*
*     QCD O(alpha_s) complete correction to \rho at mz^2
*     B.A. Kniehl, Nucl. Phys. B347 (1990) 86.
*
*     function Re(V1(r)), r=m^2/(4*mtp^2) << 1, O(r^2)
*     eq.(18), p.94
*
      complex*16 function cv1_r2 (cr)
        implicit none!
        complex*16 cr
        include "constants.h"

        cv1_r2 = (4*z3-5d0/6)*cr + 328d0/81*cr**2

        return
      end
*
*     function Re(V1(r)), r=m^2/(4*mtp^2) << 1, O(r^2)
*     eq.(19), p.95
*
      complex*16 function ca1_r2 (cr)
        implicit none!
        include "constants.h"
        complex*16 cr

        ca1_r2 = 3*(-2*z3-z2+7d0/4)+(4*z3-49d0/18)*cr+689d0/405*cr**2

        return
      end
*
*     ZF v.6.21: https://arxiv.org/pdf/hep-ph/9908433.pdf
*     function \delta\rho^(alpha_s)(mz^2)
*
      complex*16 function drho_a1__as1_mz2 (alpha,alphas,mz,mw,mh,mtp)
        implicit none!
        real*8 ctw2,stw2,qtp,qbt,vtp2,vbt2,v1mz,a1mz
        real*8 alpha,alphas,mz,mw,mh,mtp
        complex*16 crz,cv1_r2,ca1_r2
        include "constants.h"

        crz = cmplx(mz**2/4/mtp**2)
        ctw2 = mw**2/mz**2
        stw2 = 1-ctw2
        qtp =  2d0/3
        qbt = -1d0/3
        vtp2 = (1d0-4d0*abs(qtp)*stw2)**2
        vbt2 = (1d0-4d0*abs(qbt)*stw2)**2
        v1mz = 4*z3-5d0/6   + mz**2/(2*mtp**2)*328d0/81
        a1mz = 4*z3-49d0/18 + mz**2/(2*mtp**2)*689d0/405

*     massive (tb) doublet at s=mz^2: Eq.(3.4.15), p.95
        drho_a1__as1_mz2 =
     &   +1d0/pi**2/(4*stw2*ctw2)*(
     &    +mtp**2/mz**2*(vtp2*cv1_r2(crz)+ca1_r2(crz)-(23d0/4-6*z3-2*z2))
     &    -1d0/4*(vtp2*v1mz+a1mz)
     &    +1d0/4*(1+vbt2)
     &                            )

*     massless (ud) and (cs) doublets at s=mz^2: Eq.(3.4.5), p.94
        drho_a1__as1_mz2 = drho_a1__as1_mz2
     &    +1d0/pi**2/(8*stw2*ctw2)*(2+vtp2+vbt2)

        drho_a1__as1_mz2 = alpha*alphas*drho_a1__as1_mz2

        return
      end

      complex*16 function drho_a1__as1 (alpha,alphas,mz,mw,mh,mtp,s)
        implicit none!
        integer irho
        real*8 ctw2,stw2,qtp,qbt,vtp2,vbt2,v1mz,a1mz,s
        real*8 alpha,alphas,mz,mw,mh,mtp
        complex*16 crz,crs,cv1_r2,ca1_r2,cv1,ca1
        include "constants.h"

        irho = 1
        crz = cmplx(mz**2/4/mtp**2)
        crs = cmplx(    s/4/mtp**2)
        ctw2 = mw**2/mz**2
        stw2 = 1-ctw2
        qtp =  2d0/3
        qbt = -1d0/3
        vtp2 = (1d0-4d0*abs(qtp)*stw2)**2
        vbt2 = (1d0-4d0*abs(qbt)*stw2)**2

        if (abs(s-mz**2)/mz**2.lt.1d-3) then
          v1mz = 4*z3-5d0/6   + mz**2/(2*mtp**2)*328d0/81
          a1mz = 4*z3-49d0/18 + mz**2/(2*mtp**2)*689d0/405

*     massive (tb) doublet at s=mz^2: Eq.(3.4.15), p.95
          drho_a1__as1 =
     &         +1d0/pi**2/(4*stw2*ctw2)*(
     &         +mtp**2/mz**2*(vtp2*cv1_r2(crz)+ca1_r2(crz)-(23d0/4-6*z3-2*z2))
     &         -1d0/4*(vtp2*v1mz+a1mz)
     &         +1d0/4*(1+vbt2)
     &         )
c$$$         drho_a1__as1 =
c$$$     &        +1d0/pi**2/(4*stw2*ctw2)*(
c$$$     &        +mtp**2/mz**2*(vtp2*cv1(crz)+ca1(crz)-(23d0/4-6*z3-2*z2))
c$$$     &        -1d0/4*(vtp2*v1mz+a1mz)
c$$$     &        +1d0/4*(1+vbt2)
c$$$     &        )

*     massless (ud) and (cs) doublets at s=mz^2: Eq.(3.4.5), p.94
          drho_a1__as1 = drho_a1__as1
     &         +1d0/pi**2/(8*stw2*ctw2)*(2+vtp2+vbt2)
        else
*     massive (tb) doublet: Eq.(3.4.15), p.95
          drho_a1__as1 =
     &         +1d0/pi**2/(4*stw2*ctw2)*(
     &         +mtp**2/mz**2*(vtp2*cv1_r2(crz)+ca1_r2(crz)-(23d0/4-6*z3-2*z2))
     &         +mtp**2/(mz**2-s)*(vtp2*(cv1_r2(crs)-cv1_r2(crz))+ca1_r2(crs)-ca1_r2(crz))
     &         -1d0/4*(1+vbt2)*s/(mz**2-s)*log(s/mz**2)
     &         )
c$$$         drho_a1__as1 =
c$$$     &        +1d0/pi**2/(4*stw2*ctw2)*(
c$$$     &        +mtp**2/mz**2*(vtp2*cv1(crz)+ca1(crz)-(23d0/4-6*z3-2*z2))
c$$$     &        +mtp**2/(mz**2-s)*(vtp2*(cv1(crs)-cv1(crz))+ca1(crs)-ca1(crz))
c$$$     &        -1d0/4*(1+vbt2)*s/(mz**2-s)*log(s/mz**2)
c$$$     &        )

*     massless (ud) and (cs) doublets: Eq.(3.4.5), p.94
          drho_a1__as1 = drho_a1__as1
     &         -1d0/pi**2/(8*stw2*ctw2)*(2+vtp2+vbt2)*s/(mz**2-s)*log(s/mz**2)
        endif

        if (irho.eq.0) drho_a1__as1 = -mtp**2/stw2/mw**2*(pi**2+3)/24/pi**2

        drho_a1__as1 = alpha*alphas*drho_a1__as1

        return
      end
