#ifndef GENERAL_H
#define GENERAL_H

#include <cmath>
#include <iostream>
#include <limits>
#include <string>
#include <sys/stat.h>

namespace SANC {

inline double pow2(const double &x) { return x * x; }
inline double pow3(const double &x) { return x * x * x; }
inline double pow4(const double &x) { return x * x * x * x; }
inline double pow5(const double &x) { return x * x * x * x * x; }
inline double pow6(const double &x) { return x * x * x * x * x * x; }

inline double lambda(double x, double y, double z) { return pow2(x - y - z) - 4.0 * y * z; }

const double M_NAN = std::numeric_limits<double>::quiet_NaN();
const double M_EPS = std::numeric_limits<double>::epsilon();
const double M_INF = std::numeric_limits<double>::infinity();

inline bool path_exists(const std::string &name) {
  struct stat buffer;
  return (stat(name.c_str(), &buffer) == 0);
}

inline bool file_exists(const std::string &name) {
  struct stat buffer;
  if (stat(name.c_str(), &buffer)) {
    return 0;
  }
  return S_ISREG(buffer.st_mode);
}

inline bool dir_exists(const std::string &name) {
  struct stat buffer;
  if (stat(name.c_str(), &buffer)) {
    return 0;
  }
  return S_ISDIR(buffer.st_mode);
}

// Returns true if x is in range [min, max]
inline bool inRange(double x, double min, double max) { return ((min <= x) && (x <= max)); }

} // namespace SANC

#endif // GENERAL_H
