#ifndef PROCESS_H
#define PROCESS_H

#include "Event.h"
#include <string>
#include <vector>

namespace SANC {

class Info;

class Process {
public:
  Process(Info &_info);
  virtual void born(double *Qs, double *Qt, double *Qu, double *Born, double *Soft,
                    double *Hard) = 0;
  virtual void virt(double *S, double *T, double *U, double *Sigma) = 0;
  virtual void hard(double *S, double *Spr, double *Phi3, double *Eta3, double *Eta5,
                    double *Hard) = 0;
  // Returns true if the event satisfies cuts
  bool passCuts();
  // Returns true if the event satisfies cuts
  bool passUserCuts();
  int idProc;
  int kDimBorn, kDimVirt, kDimHard, kDimLL11, kDimLL22, kDimLL12;
  double Mf1, Mf2, Mf3, Mf4;
  double Mf1_2, Mf2_2, Mf3_2, Mf4_2;
  double dm, sm;
  double S, sqS, E1, E2;
  double beta1, beta2;
  double scale;
  std::vector<int> idup;
  std::string procName, arXiv;
  Event event;
  int nup; // Number of particles

protected:
  void init();
  Info &info;
};

Process &ProcessFactory(Info &info);

class Process_12_12__12_12 : public Process {
public:
  Process_12_12__12_12(Info &_info);
  void born(double *Qs, double *Qt, double *Qu, double *Born, double *Soft, double *Hard);
  void virt(double *S, double *T, double *U, double *Sigma);
  void hard(double *S, double *Spr, double *Phi3, double *Eta3, double *Eta5, double *Hard);
};

class Process_12_12__16_16 : public Process {
public:
  Process_12_12__16_16(Info &_info);
  void born(double *Qs, double *Qt, double *Qu, double *Born, double *Soft, double *Hard);
  void virt(double *S, double *T, double *U, double *Sigma);
  void hard(double *S, double *Spr, double *Phi3, double *Eta3, double *Eta5, double *Hard);
};

class Process_12_12__20_20 : public Process {
public:
  Process_12_12__20_20(Info &_info);
  void born(double *Qs, double *Qt, double *Qu, double *Born, double *Soft, double *Hard);
  void virt(double *S, double *T, double *U, double *Sigma);
  void hard(double *S, double *Spr, double *Phi3, double *Eta3, double *Eta5, double *Hard);
};

class Process_12_12__02_04 : public Process {
public:
  Process_12_12__02_04(Info &_info);
  void born(double *Qs, double *Qt, double *Qu, double *Born, double *Soft, double *Hard);
  void virt(double *S, double *T, double *U, double *Sigma);
  void hard(double *S, double *Spr, double *Phi3, double *Eta3, double *Eta5, double *Hard);
};

} // namespace SANC

#endif // PROCESS_H
