************************************************************************
* This is the FORTRAN module (nc_ha_12_12__12_12) to calculate differential
* hard photon Bremsstrahlung for the Bhabha (el^+ + el^- -> el^+ + el^- process).
*
* Copyright (C), SANC Project Team, 2002-2021.
*
* http://sanc.jinr.ru/
* E-mail: <sanc@jinr.ru>; <sanc-team@cern.ch>
************************************************************************

      subroutine nc_ha_12_12__12_12(s,spr,ph4,costh4,costh5,hard)
        implicit none!
        include 's2n_declare.h'
        real*8 ph4
        integer*4 h1,h2,h3,h4,h5,j1,j2,i
        real*8 sqs,sqspr
        real*8 costh4,costh5
        complex*16 hel_amp(2,2,2,2,2), ampISR(2,2,2,2,2), ampFSR(2,2,2,2,2)
        complex*16 ampESR(2,2,2,2,2), ampPSR(2,2,2,2,2), sp_amp(2,2,2,2,2)
        real*8 amp2(2,2,2,2,2), hard2(2,2)
        real*8 betai
        real*8 p3r1(5), p4r1(5), p3r2(5), p4r2(5)
        real*8 M_I,M_F

        real*8 pt12(5), pt34(5)
        real*8 s12, s34
        real*8 Pair
        real*8 abs2

        complex*16 DZZisr(2,2), DZZfsr(2,2), DZZesr(2,2), DZZpsr(2,2)
        complex*16 DLL2_3, DRR2_3, DRL2_3, DRL3_2
        complex*16 cc1(2,2), cc2(2,2), cc3(2,2), cc4(2,2)
        real*8 p1(5), p2(5), p3(5), p4(5), p5(5);

#ifndef GENERATOR
        real*8 mp(5)

        mp = (/mel, mel, mel, mel, 0d0/)
        ! toMomenta for cos(theta) & toMomenta1 for rapidity
        call toMomenta(s,spr,ph4,costh4,costh5,mp)
#endif

!-----------------------------------------------------------------------
!--- p(1) = px, p(2) = py, p(3) = pz, p(4) = e, p(5) = m ---------------
!-----------------------------------------------------------------------
!-----------------------------------------------------------------------
!--- 4-momenta of particles in the laboratory reference frame as input
        p1 = pg1
        p2 = pg2
        p3 = pg3
        p4 = pg4
        p5 = pg5
!--- But we work with all momenta to zero setup
!--- Do all momenta incoming
        do i = 1,4
          p3(i) = -p3(i)
          p4(i) = -p4(i)
          p5(i) = -p5(i)
        enddo

        M_I = p1(5)
        M_F = p3(5)
        sqs = sqrt(s)
        sqspr = sqrt(spr)
        betai = sqrt((sqs-2d0*M_I)*(sqs+2d0*M_I))/sqs
        betaf = sqrt((sqspr-2d0*M_F)*(sqspr+2d0*M_F))/sqspr

        call S_CC(p1,p5,-1d0,cc1)
        call S_CC(p2,p5,+1d0,cc2)

        pt12 = p3 + p2
        pt34 = p1 + p4
        s12 = Pair(pt12, pt12)
        s34 = Pair(pt34, pt34)

        DZZisr(2,2)=DLL2_3(spr)
        DZZisr(1,2)=DRL2_3(spr)
        DZZisr(2,1)=DRL3_2(spr)
        DZZisr(1,1)=DRR2_3(spr)

        DZZfsr(2,2)=DLL2_3(s)
        DZZfsr(1,2)=DRL3_2(s) ! note the transposition compared to ISR
        DZZfsr(2,1)=DRL2_3(s) ! note the transposition compared to ISR
        DZZfsr(1,1)=DRR2_3(s)

        DZZesr(2,2)=DLL2_3(s34)
        DZZesr(1,2)=DRL2_3(s34)
        DZZesr(2,1)=DRL3_2(s34)
        DZZesr(1,1)=DRR2_3(s34)

        DZZpsr(2,2)=DLL2_3(s12)
        DZZpsr(1,2)=DRL3_2(s12) ! note the transposition compared to ESR
        DZZpsr(2,1)=DRL2_3(s12) ! note the transposition compared to ESR
        DZZpsr(1,1)=DRR2_3(s12)

        call nc_ha_f1_f1__f2_f2_isrSA(p1,p2,p3,p4,p5,qel,DZZisr,ampISR)
        call nc_ha_f1_f1__f2_f2_isrSA(p3,p4,p1,p2,p5,qel,DZZfsr,ampFSR)
        call nc_ha_f1_f1__f2_f2_isrSA(p3,p2,p1,p4,p5,qel,DZZesr,ampESR)
        call nc_ha_f1_f1__f2_f2_isrSA(p1,p4,p3,p2,p5,qel,DZZpsr,ampPSR)

        ! Combine together
        do h1=1,2
          do h2=1,2
            do h3=1,2
              do h4=1,2
                do h5=1,2
                  sp_amp(h1,h2,h3,h4,h5)=ampISR(h1,h2,h3,h4,h5)+ampFSR(h3,h4,h1,h2,h5)
     &                                  -ampESR(h3,h2,h1,h4,h5)-ampPSR(h1,h4,h3,h2,h5)
                enddo
              enddo
            enddo
          enddo
        enddo

        do h1=1,2
          do h2=1,2
            do h3=1,2
              do h4=1,2
                do h5=1,2
                  hel_amp(h1,h2,h3,h4,h5)=0d0
                  do j1 = 1,2
                    do j2 = 1,2
                      hel_amp(h1,h2,h3,h4,h5)=hel_amp(h1,h2,h3,h4,h5)
     &                +cc1(j1,h1)*cc2(j2,h2)*sp_amp(j1,j2,h3,h4,h5)
                    enddo
                  enddo
                enddo
              enddo
            enddo
          enddo
        enddo

! phase space volume
        volum =  1d0/2048d0/pi**4*(s-spr)/s**2*betaf/betai*conhc

! Cross to channel and square
        hard2(:,:) = 0d0
        do h1=1,2
          do h2=1,2
            do h3=1,2
              do h4=1,2
                do h5=1,2
                  amp2(h1,h2,h3,h4,h5) = abs2(hel_amp(h1,h2,3-h3,3-h4,3-h5))
                  hard2(h1,h2) = hard2(h1,h2) + amp2(h1,h2,h3,h4,h5)
                enddo
              enddo
            enddo
          enddo
        enddo

        if (alr.eq.0) then
          hard =
     &        ((1d0+lamep)*(1d0+lamem)*hard2(1,1)
     &        +(1d0+lamep)*(1d0-lamem)*hard2(1,2)
     &        +(1d0-lamep)*(1d0+lamem)*hard2(2,1)
     &        +(1d0-lamep)*(1d0-lamem)*hard2(2,2))/4d0
        elseif (alr.eq.1) then
          hard =  hard2(1,2)-hard2(2,1)
        elseif (alr.eq.2) then
          hard =  hard2(1,2)+hard2(2,1)
        elseif (alr.eq.3) then
          hard = (hard2(1,2)+hard2(2,2)-hard2(1,1)-hard2(2,1))/2d0
        elseif (alr.eq.4) then
          hard = (hard2(1,2)+hard2(2,2)+hard2(1,1)+hard2(2,1))/2d0
        endif

        hard = hard*volum*e**6
        hard = hard*cfprime
        ! print *,hard2*volum*e**6*cfprime
        if (hard.ne.hard) then
          print *,"NAN hard:",s,spr,ph4,costh4,costh5
          hard = 0d0
        endif
        return
      end
