************************************************************************
* sanc_nc_v1.30 package.
************************************************************************
* File (nc_ha_13_1__13_16_16.f) is created on Fri Aug 16 13:12:03 CEST 2013.
************************************************************************
* This is the FORTRAN module (nc_ha_13_1__13_16_16) to calculate differential
* hard photon Bremsstrahlung for the anti-up + a -> anti-up + mo^+ + mo^- process.
*
* It is produced by s2n package of SANC (v1.10) Project.
* Copyright (C), SANC Project Team, 2002-2013.
*
* http://sanc.jinr.ru/
* http://pcphsanc.cern.ch/
* E-mail: <sanc@jinr.ru>
************************************************************************
      subroutine nc_ha_13_1__13_16_16 (s,spr,ph3,costh3,costh5,hard)
        implicit none!
        include 's2n_declare.h'

        real*8 kappaz,sq,sqspr,ps
        real*8 a1z,a2z,v1z,v2z,vaz
        real*8 p1p2,p1p3,p1p4,p1p5,p2p3,p2p4,p2p5,p3p4,p3p5,p4p5
        real*8 ph3,cosph3,sinph3,costh3,costh5,sinth3,sinth5
        real*8 sqrtlssprup,isqrtlssprup
        complex*16 chizs,chizsc,chizspr,chizsprc,chizps,chizpsc
        real*8 betasprmomo,ibetasprmomo
        real*8 iz1up,iz2up,iz3mo,iz4mo
        real*8 v0ps,v0spr,v0sprps,a0ps,a0spr,a0sprps,vaps,vaspr,vasprps,a
     &   1sprps

        cmz2 = mz2

        sq = dsqrt(s)
        sqspr = dsqrt(spr)

        cosph3 = dcos(ph3)
        sinph3 = dsin(ph3)
        sinth3 = dsqrt(1d0-costh3**2)
        sinth5 = dsqrt(1d0-costh5**2)

        kappaz   = gf*rzm2/(dsqrt(2d0)*8d0*pi)/alpha
        if (irun.eq.0) then
          chizs = 4d0*kappaz*s/(s-cmz2)
          chizspr = 4d0*kappaz*spr/(spr-cmz2)
        else
          chizs = 4d0*kappaz*s/(s-dcmplx(mz**2,-s*wz/mz))
          chizspr = 4d0*kappaz*spr/(spr-dcmplx(mz**2,-spr*wz/mz))
        endif

        sqrtlssprup = sqrt(s**2-2d0*s*(spr+rupm2)+(spr-rupm2)**2)
        isqrtlssprup = 1d0/sqrtlssprup
        ps=(s+mup**2)*(s-spr+mup**2)/2/s-2*mup**2+(s-mup**2)*sqrtlssprup*costh5/2/s

        chizps   = 4d0*kappaz*ps/(ps+mz**2)
        chizsc   = dconjg(chizs)
        chizsprc = dconjg(chizspr)
        chizpsc  = dconjg(chizps)

        a1z = aup*amo
        a2z = 4d0*vup*aup*vmo*amo
        v1z = vup*vmo
        v2z = (vup**2+aup**2)*(vmo**2+amo**2)
        vaz = (vup**2+aup**2)*(vmo**2-amo**2)

        betasprmomo = sqrt(1d0-4d0*rmom2/spr)
        ibetasprmomo = 1d0/betasprmomo

        v0ps =
     &   +qup**2*qmo**2
     &   +qup*qmo*(chizps+chizpsc)*v1z
     &   +chizps*chizpsc*v2z

        v0spr =
     &   +qup**2*qmo**2
     &   +qup*qmo*(chizspr+chizsprc)*v1z
     &   +chizspr*chizsprc*v2z

        v0sprps =
     &   +qup**2*qmo**2
     &   +qup*qmo*(chizspr+chizsprc)*v1z
     &   +chizps*chizpsc*v2z

        a0ps =
     &   +qup*qmo*(chizps+chizpsc)*a1z
     &   +chizps*chizpsc*a2z

        a0spr =
     &   +qup*qmo*(chizspr+chizsprc)*a1z
     &   +chizspr*chizsprc*a2z

        a0sprps =
     &   +qup*qmo*(chizspr+chizsprc)*a1z
     &   +chizps*chizpsc*a2z

        vaps =
     &   +qup**2*qmo**2
     &   +qup*qmo*(chizps+chizpsc)*v1z
     &   +chizps*chizpsc*vaz

        vaspr =
     &   +qup**2*qmo**2
     &   +qup*qmo*(chizspr+chizsprc)*v1z
     &   +chizspr*chizsprc*vaz

        vasprps =
     &   +2d0*qup**2*qmo**2
     &   +qup*qmo*(chizspr+chizsprc+chizps+chizpsc)*v1z
     &   +(chizspr*chizpsc+chizsprc*chizps)*vaz

        a1sprps =
     &   -(chizspr+chizsprc-chizps-chizpsc)*a1z

        p1p2=
     &   +sqrtlssprup*costh5*(-1d0/4+1d0/4*mup**2/s)
     &   +1d0/4*spr-1d0/4*s+1d0/4*mup**2/s*spr-1d0/2*mup**2-1d0/4*mup**4/s

        p1p3=
     &   +sqrtlssprup**2*(-1d0/8/s)
     &   +sqrtlssprup*betasprmomo*costh3*(1d0/4)
     &   +1d0/8/s*spr**2-1d0/8*s-1d0/4*mup**2/s*spr+1d0/8*mup**4/s

        p1p4=
     &   +sqrtlssprup**2*(-1d0/8/s)
     &   +sqrtlssprup*betasprmomo*costh3*(-1d0/4)
     &   +1d0/8/s*spr**2-1d0/8*s-1d0/4*mup**2/s*spr+1d0/8*mup**4/s

        p1p5=
     &   +sqrtlssprup*costh5*(1d0/4-1d0/4*mup**2/s)
     &   +1d0/4*spr-1d0/4*s-1d0/4*mup**2/s*spr+1d0/4*mup**4/s

        p2p3=
     &   +sqrtlssprup*betasprmomo*costh3*(1d0/8+1d0/8*mup**2/s)
     &   +sqrtlssprup*costh5*(1d0/8-1d0/8*mup**2/s)
     &   +betasprmomo*sinph3*sinth3*sinth5*(-1d0/4*sq*sqspr+1d0/4*sq*sqspr
     &   *mup**2/s)
     &   +betasprmomo*costh3*costh5*(-1d0/8*spr-1d0/8*s+1d0/8*mup**2/s*spr
     &   +1d0/4*mup**2-1d0/8*mup**4/s)
     &   -1d0/8*spr-1d0/8*s-1d0/8*mup**2/s*spr+1d0/8*mup**4/s

        p2p4=
     &   +sqrtlssprup*betasprmomo*costh3*(-1d0/8-1d0/8*mup**2/s)
     &   +sqrtlssprup*costh5*(1d0/8-1d0/8*mup**2/s)
     &   +betasprmomo*sinph3*sinth3*sinth5*(1d0/4*sq*sqspr-1d0/4*sq*sqspr*
     &   mup**2/s)
     &   +betasprmomo*costh3*costh5*(1d0/8*spr+1d0/8*s-1d0/8*mup**2/s*spr-
     &   1d0/4*mup**2+1d0/8*mup**4/s)
     &   -1d0/8*spr-1d0/8*s-1d0/8*mup**2/s*spr+1d0/8*mup**4/s

        p2p5=
     &   -1d0/2*s+1d0/2*mup**2

        p3p4=
     &   -1d0/2*spr+mmo**2

        p3p5=
     &   +sqrtlssprup*betasprmomo*costh3*(1d0/8-1d0/8*mup**2/s)
     &   +sqrtlssprup*costh5*(-1d0/8+1d0/8*mup**2/s)
     &   +betasprmomo*sinph3*sinth3*sinth5*(1d0/4*sq*sqspr-1d0/4*sq*sqspr*
     &   mup**2/s)
     &   +betasprmomo*costh3*costh5*(1d0/8*spr+1d0/8*s-1d0/8*mup**2/s*spr-
     &   1d0/4*mup**2+1d0/8*mup**4/s)
     &   -1d0/8*spr-1d0/8*s+1d0/8*mup**2/s*spr+1d0/4*mup**2-1d0/8*mup**4/s

        p4p5=
     &   +sqrtlssprup*betasprmomo*costh3*(-1d0/8+1d0/8*mup**2/s)
     &   +sqrtlssprup*costh5*(-1d0/8+1d0/8*mup**2/s)
     &   +betasprmomo*sinph3*sinth3*sinth5*(-1d0/4*sq*sqspr+1d0/4*sq*sqspr
     &   *mup**2/s)
     &   +betasprmomo*costh3*costh5*(-1d0/8*spr-1d0/8*s+1d0/8*mup**2/s*spr
     &   +1d0/4*mup**2-1d0/8*mup**4/s)
     &   -1d0/8*spr-1d0/8*s+1d0/8*mup**2/s*spr+1d0/4*mup**2-1d0/8*mup**4/s

        iz1up=
     &   +1d0/(mup**2/s+1d0/4*sqrtlssprup**2*sinth5**2/s**2)/(s-mup**2)*(1
     &   -1d0/2/s*spr+1d0/2*sqrtlssprup*costh5/s)
     &   +1d0/(mup**2/s+1d0/4*sqrtlssprup**2*sinth5**2/s**2)*(-1d0/2/s)

        iz2up=
     &   +1d0/(s-mup**2)*(1)

        iz3mo=
     &   +1d0/(1d0/4*spr+1d0/4*s-1d0/4*mup**2/s*spr-1d0/2*mup**2+1d0/4*mup
     &   **4/s-1d0/4*sqrtlssprup*betasprmomo*costh3+1d0/4*sqrtlssprup*beta
     &   sprmomo*costh3*mup**2/s+1d0/4*sqrtlssprup*costh5-1d0/4*sqrtlsspru
     &   p*costh5*mup**2/s-1d0/2*betasprmomo*sinph3*sinth3*sinth5*sq*sqspr
     &   +1d0/2*betasprmomo*sinph3*sinth3*sinth5*sq*sqspr*mup**2/s-1d0/4*b
     &   etasprmomo*costh3*costh5*spr-1d0/4*betasprmomo*costh3*costh5*s+1d
     &   0/4*betasprmomo*costh3*costh5*mup**2/s*spr+1d0/2*betasprmomo*cost
     &   h3*costh5*mup**2-1d0/4*betasprmomo*costh3*costh5*mup**4/s)*(1)

        iz4mo=
     &   +1d0/(1d0/4*spr+1d0/4*s-1d0/4*mup**2/s*spr-1d0/2*mup**2+1d0/4*mup
     &   **4/s+1d0/4*sqrtlssprup*betasprmomo*costh3-1d0/4*sqrtlssprup*beta
     &   sprmomo*costh3*mup**2/s+1d0/4*sqrtlssprup*costh5-1d0/4*sqrtlsspru
     &   p*costh5*mup**2/s+1d0/2*betasprmomo*sinph3*sinth3*sinth5*sq*sqspr
     &   -1d0/2*betasprmomo*sinph3*sinth3*sinth5*sq*sqspr*mup**2/s+1d0/4*b
     &   etasprmomo*costh3*costh5*spr+1d0/4*betasprmomo*costh3*costh5*s-1d
     &   0/4*betasprmomo*costh3*costh5*mup**2/s*spr-1d0/2*betasprmomo*cost
     &   h3*costh5*mup**2+1d0/4*betasprmomo*costh3*costh5*mup**4/s)*(1)

        hard=
     &   +v0ps*iz3mo**2*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*
     &   (s-spr)*(-p1p3*p2p4*mmo**2-p1p4*p2p3*mmo**2+p1p4*p2p5*mmo**2+p1p5
     &   *p2p4*mmo**2-p3p4*mup**2*mmo**2+p4p5*mup**2*mmo**2)
     &   +v0ps*iz3mo*iz4mo*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2
     &   /s*(s-spr)*(-2*p1p3*p2p4*p3p4+p1p3*p2p5*p3p4-2*p1p4*p2p3*p3p4+p1p
     &   4*p2p5*p3p4+p1p5*p2p3*p3p4+p1p5*p2p4*p3p4-2*p3p4**2*mup**2)
     &   +v0ps*iz3mo*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*(s-
     &   spr)*(-1d0/2*mup**2*mmo**2+p1p3*p2p3-1d0/2*p1p3*p2p4-1d0/2*p1p4*p
     &   2p3+1d0/2*p1p4*p2p5+1d0/2*p1p5*p2p4-p3p4*mup**2+1d0/2*p4p5*mup**2
     &   )
     &   +v0ps*iz4mo**2*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*
     &   (s-spr)*(-p1p3*p2p4*mmo**2+p1p3*p2p5*mmo**2-p1p4*p2p3*mmo**2+p1p5
     &   *p2p3*mmo**2-p3p4*mup**2*mmo**2+p3p5*mup**2*mmo**2)
     &   +v0ps*iz4mo*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*(s-
     &   spr)*(-1d0/2*mup**2*mmo**2-1d0/2*p1p3*p2p4+1d0/2*p1p3*p2p5-1d0/2*
     &   p1p4*p2p3+p1p4*p2p4+1d0/2*p1p5*p2p3-p3p4*mup**2+1d0/2*p3p5*mup**2
     &   )
     &   +v0spr*iz1up**2*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**
     &   2*(s-spr)*(-p1p3*p2p4*mup**2-p1p4*p2p3*mup**2+p2p3*p4p5*mup**2+p2
     &   p4*p3p5*mup**2-p3p4*mup**4)
     &   +v0spr*iz1up*iz2up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/sp
     &   r**2*(s-spr)*(-2*p1p2*p1p3*p2p4-p1p2*p1p3*p4p5-2*p1p2*p1p4*p2p3-p
     &   1p2*p1p4*p3p5+p1p2*p2p3*p4p5+p1p2*p2p4*p3p5-2*p1p2*p3p4*mup**2-2*
     &   p3p5*p4p5*mup**2)
     &   +v0spr*iz1up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**2*(
     &   s-spr)*(-p1p3*p1p4-1d0/2*p1p3*p2p4-1d0/2*p1p4*p2p3+1d0/2*p2p3*p4p
     &   5+1d0/2*p2p4*p3p5)
     &   +v0spr*iz2up**2*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**
     &   2*(s-spr)*(-p1p3*p2p4*mup**2-p1p3*p4p5*mup**2-p1p4*p2p3*mup**2-p1
     &   p4*p3p5*mup**2-p3p4*mup**4)
     &   +v0spr*iz2up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**2*(
     &   s-spr)*(1d0/2*p1p3*p2p4+1d0/2*p1p3*p4p5+1d0/2*p1p4*p2p3+1d0/2*p1p
     &   4*p3p5+p2p3*p2p4)
     &   +v0sprps*iz1up*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(-p1p3*p1p4*p2p3+1d0/2*p1p3*p1p4*p2p5+1d0/2*p1p3*
     &   p2p3*p4p5-p1p3*p3p4*mup**2+1d0/2*p1p3*p4p5*mup**2-p1p3**2*p2p4)
     &   +v0sprps*iz1up*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(p1p3*p1p4*p2p4-1d0/2*p1p3*p1p4*p2p5-1d0/2*p1p4*p
     &   2p4*p3p5+p1p4*p3p4*mup**2-1d0/2*p1p4*p3p5*mup**2+p1p4**2*p2p3)
     &   +v0sprps*iz1up*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(-1d0/4*p1p2*p1p3+1d0/4*p1p2*p1p4-1d0/4*p1p3*p2p4-1d0/4
     &   *p1p3*mup**2+1d0/4*p1p4*p2p3+1d0/4*p1p4*mup**2+1d0/4*p2p3*mup**2-
     &   1d0/4*p2p4*mup**2-1d0/4*p3p5*mup**2+1d0/4*p4p5*mup**2)
     &   +v0sprps*iz2up*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(p1p3*p2p3*p2p4+1d0/2*p1p3*p2p3*p4p5+p1p4*p2p3**2
     &   -1d0/2*p1p5*p2p3*p2p4+p2p3*p3p4*mup**2-1d0/2*p2p3*p4p5*mup**2)
     &   +v0sprps*iz2up*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(-p1p3*p2p4**2-p1p4*p2p3*p2p4-1d0/2*p1p4*p2p4*p3p
     &   5+1d0/2*p1p5*p2p3*p2p4-p2p4*p3p4*mup**2+1d0/2*p2p4*p3p5*mup**2)
     &   +v0sprps*iz2up*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(1d0/4*p1p2*p2p3-1d0/4*p1p2*p2p4+1d0/4*p1p3*p2p4-1d0/4*
     &   p1p3*mup**2-1d0/4*p1p4*p2p3+1d0/4*p1p4*mup**2+1d0/4*p2p3*mup**2-1
     &   d0/4*p2p4*mup**2-1d0/4*p3p5*mup**2+1d0/4*p4p5*mup**2)
     &   +v0sprps*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(-1d0/4*p1p3*p2p4+1d0/4*p1p3*p3p4+1d0/4*p1p4*p2p3-1d0/4
     &   *p1p4*mmo**2+1d0/4*p2p3*p3p4-1d0/4*p2p4*mmo**2)
     &   +v0sprps*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(-1d0/4*p1p3*p2p4+1d0/4*p1p3*mmo**2+1d0/4*p1p4*p2p3-1d0
     &   /4*p1p4*p3p4+1d0/4*p2p3*mmo**2-1d0/4*p2p4*p3p4)
     &   +v0sprps*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/spr*(s-s
     &   pr)*(1d0/4*p1p3-1d0/4*p1p4+1d0/4*p2p3-1d0/4*p2p4)
     &   +a0ps*iz3mo**2*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*
     &   (s-spr)*(-p1p3*p2p4*mmo**2+p1p4*p2p3*mmo**2-p1p4*p2p5*mmo**2+p1p5
     &   *p2p4*mmo**2)
     &   +a0ps*iz3mo*iz4mo*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2
     &   /s*(s-spr)*(-2*p1p3*p2p4*p3p4+p1p3*p2p5*p3p4+2*p1p4*p2p3*p3p4-p1p
     &   4*p2p5*p3p4-p1p5*p2p3*p3p4+p1p5*p2p4*p3p4)
     &   +a0ps*iz3mo*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*(s-
     &   spr)*(-1d0/2*p1p3*p2p4+1d0/2*p1p4*p2p3-1d0/2*p1p4*p2p5+1d0/2*p1p5
     &   *p2p4)
     &   +a0ps*iz4mo**2*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*
     &   (s-spr)*(-p1p3*p2p4*mmo**2+p1p3*p2p5*mmo**2+p1p4*p2p3*mmo**2-p1p5
     &   *p2p3*mmo**2)
     &   +a0ps*iz4mo*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*(s-
     &   spr)*(-1d0/2*p1p3*p2p4+1d0/2*p1p3*p2p5+1d0/2*p1p4*p2p3-1d0/2*p1p5
     &   *p2p3)
     &   +a0spr*iz1up**2*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**
     &   2*(s-spr)*(-p1p3*p2p4*mup**2+p1p4*p2p3*mup**2-p2p3*p4p5*mup**2+p2
     &   p4*p3p5*mup**2)
     &   +a0spr*iz1up*iz2up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/sp
     &   r**2*(s-spr)*(-2*p1p2*p1p3*p2p4-p1p2*p1p3*p4p5+2*p1p2*p1p4*p2p3+p
     &   1p2*p1p4*p3p5-p1p2*p2p3*p4p5+p1p2*p2p4*p3p5)
     &   +a0spr*iz1up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**2*(
     &   s-spr)*(-1d0/2*p1p3*p2p4+1d0/2*p1p4*p2p3-1d0/2*p2p3*p4p5+1d0/2*p2
     &   p4*p3p5)
     &   +a0spr*iz2up**2*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**
     &   2*(s-spr)*(-p1p3*p2p4*mup**2-p1p3*p4p5*mup**2+p1p4*p2p3*mup**2+p1
     &   p4*p3p5*mup**2)
     &   +a0spr*iz2up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**2*(
     &   s-spr)*(1d0/2*p1p3*p2p4+1d0/2*p1p3*p4p5-1d0/2*p1p4*p2p3-1d0/2*p1p
     &   4*p3p5)
     &   +a0sprps*iz1up*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(p1p3*p1p4*p2p3-1d0/2*p1p3*p1p4*p2p5-1d0/2*p1p3*p
     &   2p3*p4p5-p1p3**2*p2p4+1d0/2*p2p5*p4p5/mz**2*mup**2*mmo**2)
     &   +a0sprps*iz1up*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(p1p3*p1p4*p2p4-1d0/2*p1p3*p1p4*p2p5-1d0/2*p1p4*p
     &   2p4*p3p5-p1p4**2*p2p3+1d0/2*p2p5*p3p5/mz**2*mup**2*mmo**2)
     &   +a0sprps*iz1up*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(-1d0/4*p1p2*p1p3-1d0/4*p1p2*p1p4-1d0/4*p1p3*p2p4-1d0/4
     &   *p1p4*p2p3-1d0/4*p2p3*mup**2-1d0/4*p2p4*mup**2-1d0/2*p2p5/mz**2*m
     &   up**2*mmo**2)
     &   +a0sprps*iz2up*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(p1p3*p2p3*p2p4+1d0/2*p1p3*p2p3*p4p5-p1p4*p2p3**2
     &   -1d0/2*p1p5*p2p3*p2p4+1d0/2*p1p5*p4p5/mz**2*mup**2*mmo**2)
     &   +a0sprps*iz2up*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(-p1p3*p2p4**2+p1p4*p2p3*p2p4+1d0/2*p1p4*p2p4*p3p
     &   5-1d0/2*p1p5*p2p3*p2p4+1d0/2*p1p5*p3p5/mz**2*mup**2*mmo**2)
     &   +a0sprps*iz2up*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(-1d0/4*p1p2*p2p3-1d0/4*p1p2*p2p4+1d0/4*p1p3*p2p4-1d0/4
     &   *p1p3*mup**2+1d0/4*p1p4*p2p3-1d0/4*p1p4*mup**2-1d0/2*p1p5/mz**2*m
     &   up**2*mmo**2)
     &   +a0sprps*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(-1d0/4*p1p3*p2p4+1d0/4*p1p3*p3p4-1d0/4*p1p4*p2p3+1d0/4
     &   *p1p4*mmo**2-1d0/4*p2p3*p3p4-1d0/4*p2p4*mmo**2+1d0/2*p4p5/mz**2*m
     &   up**2*mmo**2)
     &   +a0sprps*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(-1d0/4*p1p3*p2p4+1d0/4*p1p3*mmo**2-1d0/4*p1p4*p2p3+1d0
     &   /4*p1p4*p3p4-1d0/4*p2p3*mmo**2-1d0/4*p2p4*p3p4+1d0/2*p3p5/mz**2*m
     &   up**2*mmo**2)
     &   +a0sprps*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/spr*(s-s
     &   pr)*(-1d0/2/mz**2*mup**2*mmo**2+1d0/4*p1p3+1d0/4*p1p4-1d0/4*p2p3-
     &   1d0/4*p2p4)
     &   +vaps*iz3mo**2*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*
     &   (s-spr)*(2*mup**2*mmo**4+p1p2*mmo**4)
     &   +vaps*iz3mo*iz4mo*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2
     &   /s*(s-spr)*(2*p1p2*p3p4*mmo**2-2*p1p5*p2p5*mmo**2+4*p3p4*mup**2*m
     &   mo**2)
     &   +vaps*iz4mo**2*betasprmomo/ps**2/(s-mup**2)/pi*alpha**3*qmo**2/s*
     &   (s-spr)*(2*mup**2*mmo**4+p1p2*mmo**4)
     &   +vaspr*iz1up**2*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**
     &   2*(s-spr)*(2*mup**4*mmo**2+p1p2*mup**2*mmo**2-p2p5*mup**2*mmo**2)
     &
     &   +vaspr*iz1up*iz2up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/sp
     &   r**2*(s-spr)*(4*p1p2*mup**2*mmo**2+2*p1p2**2*mmo**2)
     &   +vaspr*iz1up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**2*(
     &   s-spr)*(-1d0/2*mup**2*mmo**2+p1p2*mmo**2-1d0/2*p2p5*mmo**2)
     &   +vaspr*iz2up**2*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**
     &   2*(s-spr)*(2*mup**4*mmo**2+p1p2*mup**2*mmo**2+p1p5*mup**2*mmo**2)
     &
     &   +vaspr*iz2up*betasprmomo/(s-mup**2)/pi*alpha**3*qup**2/s/spr**2*(
     &   s-spr)*(1d0/2*mup**2*mmo**2-p1p2*mmo**2-1d0/2*p1p5*mmo**2)
     &   +vasprps*iz1up*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(p1p2*p1p3*mmo**2-1d0/2*p1p3*p2p5*mmo**2+2*p1p3*m
     &   up**2*mmo**2)
     &   +vasprps*iz1up*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(-p1p2*p1p4*mmo**2+1d0/2*p1p4*p2p5*mmo**2-2*p1p4*
     &   mup**2*mmo**2)
     &   +vasprps*iz2up*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(-p1p2*p2p3*mmo**2-1d0/2*p1p5*p2p3*mmo**2-2*p2p3*
     &   mup**2*mmo**2)
     &   +vasprps*iz2up*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qm
     &   o/s/spr*(s-spr)*(p1p2*p2p4*mmo**2+1d0/2*p1p5*p2p4*mmo**2+2*p2p4*m
     &   up**2*mmo**2)
     &   +vasprps*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(-1d0/4*p1p3*mmo**2-1d0/4*p1p5*mmo**2-1d0/4*p2p3*mmo**2
     &   -1d0/4*p2p5*mmo**2)
     &   +vasprps*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup*qmo/s/sp
     &   r*(s-spr)*(1d0/4*p1p4*mmo**2+1d0/4*p1p5*mmo**2+1d0/4*p2p4*mmo**2+
     &   1d0/4*p2p5*mmo**2)
     &   +a1sprps*iz1up*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2
     &   *qmo**2/s/spr*(s-spr)*(1d0/2*p2p5*p4p5/mz**2*mup**2*mmo**2-1d0/2*
     &   p2p5*mup**2*mmo**2-1d0/2*p4p5*mup**2*mmo**2)
     &   +a1sprps*iz1up*iz3mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*al
     &   pha**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p1p3*p3p4/mz**4*mup**2*mmo*
     &   *2+4*p1p2*p1p3*p4p5/mz**4*mup**2*mmo**2+8*p1p2*p1p3/mz**4*mup**2*
     &   mmo**4-4*p1p3*p1p4/mz**2*mup**2*mmo**2+4*p1p3*p2p3/mz**2*mup**2*m
     &   mo**2+4*p1p3*p2p4/mz**2*mup**2*mmo**2+4*p1p3*p2p5*p3p4/mz**4*mup*
     &   *2*mmo**2-2*p1p3*p2p5*p4p5/mz**4*mup**2*mmo**2-4*p1p3*p2p5/mz**4*
     &   mup**2*mmo**4-2*p1p3*p2p5/mz**2*mup**2*mmo**2-8*p1p3*p3p4/mz**4*m
     &   up**4*mmo**2+2*p1p3*p3p4*mup**2+4*p1p3*p4p5/mz**4*mup**4*mmo**2+2
     &   *p1p3*p4p5/mz**2*mup**2*mmo**2-p1p3*p4p5*mup**2+8*p1p3/mz**4*mup*
     &   *4*mmo**4+4*p1p3*mup**2*mmo**2-4*p1p3**2/mz**2*mup**2*mmo**2-2*p2
     &   p5*p4p5/mz**2*mup**2*mmo**2)
     &   +a1sprps*iz1up*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2
     &   *qmo**2/s/spr*(s-spr)*(1d0/2*p2p5*p3p5/mz**2*mup**2*mmo**2-1d0/2*
     &   p2p5*mup**2*mmo**2-1d0/2*p3p5*mup**2*mmo**2)
     &   +a1sprps*iz1up*iz4mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*al
     &   pha**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p1p4*p3p4/mz**4*mup**2*mmo**
     &   2-4*p1p2*p1p4*p3p5/mz**4*mup**2*mmo**2-8*p1p2*p1p4/mz**4*mup**2*m
     &   mo**4+4*p1p3*p1p4/mz**2*mup**2*mmo**2-4*p1p4*p2p3/mz**2*mup**2*mm
     &   o**2-4*p1p4*p2p4/mz**2*mup**2*mmo**2-4*p1p4*p2p5*p3p4/mz**4*mup**
     &   2*mmo**2+2*p1p4*p2p5*p3p5/mz**4*mup**2*mmo**2+4*p1p4*p2p5/mz**4*m
     &   up**2*mmo**4+2*p1p4*p2p5/mz**2*mup**2*mmo**2+8*p1p4*p3p4/mz**4*mu
     &   p**4*mmo**2-2*p1p4*p3p4*mup**2-4*p1p4*p3p5/mz**4*mup**4*mmo**2-2*
     &   p1p4*p3p5/mz**2*mup**2*mmo**2+p1p4*p3p5*mup**2-8*p1p4/mz**4*mup**
     &   4*mmo**4-4*p1p4*mup**2*mmo**2+4*p1p4**2/mz**2*mup**2*mmo**2+2*p2p
     &   5*p3p5/mz**2*mup**2*mmo**2)
     &   +a1sprps*iz1up*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2*qmo**
     &   2/s/spr*(s-spr)*(-1d0/2*p2p5/mz**2*mup**2*mmo**2+1d0/2*p3p4*mup**
     &   2-1d0/4*p3p5*mup**2-1d0/4*p4p5*mup**2)
     &   +a1sprps*iz1up*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3
     &   *qup*qmo/s/spr*(s-spr)*(-2*p1p2*p1p3/mz**4*mup**2*mmo**2+2*p1p2*p
     &   1p4/mz**4*mup**2*mmo**2+p1p3*p2p5/mz**4*mup**2*mmo**2-2*p1p3/mz**
     &   4*mup**4*mmo**2-p1p3/mz**2*mup**2*mmo**2+1d0/2*p1p3*mup**2-p1p4*p
     &   2p5/mz**4*mup**2*mmo**2+2*p1p4/mz**4*mup**4*mmo**2+p1p4/mz**2*mup
     &   **2*mmo**2-1d0/2*p1p4*mup**2+1d0/2*p3p5*mup**2-1d0/2*p4p5*mup**2)
     &
     &   +a1sprps*iz2up*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2
     &   *qmo**2/s/spr*(s-spr)*(1d0/2*p1p5*p4p5/mz**2*mup**2*mmo**2-1d0/2*
     &   p1p5*mup**2*mmo**2+1d0/2*p4p5*mup**2*mmo**2)
     &   +a1sprps*iz2up*iz3mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*al
     &   pha**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p2p3*p3p4/mz**4*mup**2*mmo**
     &   2-4*p1p2*p2p3*p4p5/mz**4*mup**2*mmo**2-8*p1p2*p2p3/mz**4*mup**2*m
     &   mo**4+4*p1p3*p2p3/mz**2*mup**2*mmo**2+4*p1p4*p2p3/mz**2*mup**2*mm
     &   o**2+4*p1p5*p2p3*p3p4/mz**4*mup**2*mmo**2-2*p1p5*p2p3*p4p5/mz**4*
     &   mup**2*mmo**2-4*p1p5*p2p3/mz**4*mup**2*mmo**4-2*p1p5*p2p3/mz**2*m
     &   up**2*mmo**2+2*p1p5*p4p5/mz**2*mup**2*mmo**2-4*p2p3*p2p4/mz**2*mu
     &   p**2*mmo**2+8*p2p3*p3p4/mz**4*mup**4*mmo**2-2*p2p3*p3p4*mup**2-4*
     &   p2p3*p4p5/mz**4*mup**4*mmo**2-2*p2p3*p4p5/mz**2*mup**2*mmo**2+p2p
     &   3*p4p5*mup**2-8*p2p3/mz**4*mup**4*mmo**4-4*p2p3*mup**2*mmo**2-4*p
     &   2p3**2/mz**2*mup**2*mmo**2)
     &   +a1sprps*iz2up*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2
     &   *qmo**2/s/spr*(s-spr)*(1d0/2*p1p5*p3p5/mz**2*mup**2*mmo**2-1d0/2*
     &   p1p5*mup**2*mmo**2+1d0/2*p3p5*mup**2*mmo**2)
     &   +a1sprps*iz2up*iz4mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*al
     &   pha**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p2p4*p3p4/mz**4*mup**2*mmo*
     &   *2+4*p1p2*p2p4*p3p5/mz**4*mup**2*mmo**2+8*p1p2*p2p4/mz**4*mup**2*
     &   mmo**4-4*p1p3*p2p4/mz**2*mup**2*mmo**2-4*p1p4*p2p4/mz**2*mup**2*m
     &   mo**2-4*p1p5*p2p4*p3p4/mz**4*mup**2*mmo**2+2*p1p5*p2p4*p3p5/mz**4
     &   *mup**2*mmo**2+4*p1p5*p2p4/mz**4*mup**2*mmo**4+2*p1p5*p2p4/mz**2*
     &   mup**2*mmo**2-2*p1p5*p3p5/mz**2*mup**2*mmo**2+4*p2p3*p2p4/mz**2*m
     &   up**2*mmo**2-8*p2p4*p3p4/mz**4*mup**4*mmo**2+2*p2p4*p3p4*mup**2+4
     &   *p2p4*p3p5/mz**4*mup**4*mmo**2+2*p2p4*p3p5/mz**2*mup**2*mmo**2-p2
     &   p4*p3p5*mup**2+8*p2p4/mz**4*mup**4*mmo**4+4*p2p4*mup**2*mmo**2+4*
     &   p2p4**2/mz**2*mup**2*mmo**2)
     &   +a1sprps*iz2up*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2*qmo**
     &   2/s/spr*(s-spr)*(-1d0/2*p1p5/mz**2*mup**2*mmo**2-1d0/2*p3p4*mup**
     &   2+1d0/4*p3p5*mup**2+1d0/4*p4p5*mup**2)
     &   +a1sprps*iz2up*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3
     &   *qup*qmo/s/spr*(s-spr)*(2*p1p2*p2p3/mz**4*mup**2*mmo**2-2*p1p2*p2
     &   p4/mz**4*mup**2*mmo**2+p1p5*p2p3/mz**4*mup**2*mmo**2-p1p5*p2p4/mz
     &   **4*mup**2*mmo**2+2*p2p3/mz**4*mup**4*mmo**2+p2p3/mz**2*mup**2*mm
     &   o**2-1d0/2*p2p3*mup**2-2*p2p4/mz**4*mup**4*mmo**2-p2p4/mz**2*mup*
     &   *2*mmo**2+1d0/2*p2p4*mup**2+1d0/2*p3p5*mup**2-1d0/2*p4p5*mup**2)
     &   +a1sprps*iz3mo**2*betasprmomo*chizpsc/ps**2/(s-mup**2)*a1z/pi*alp
     &   ha**3*qmo**2/s*(s-spr)*(8/mz**4*mup**4*mmo**6+4*mup**2*mmo**4-8*p
     &   1p2*p3p4/mz**4*mup**2*mmo**4+8*p1p2*p4p5/mz**4*mup**2*mmo**4+8*p1
     &   p2/mz**4*mup**2*mmo**6-4*p1p3/mz**2*mup**2*mmo**4-4*p1p4/mz**2*mu
     &   p**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**4+4*p2p3/mz**2*mup**2*mmo**4
     &   +4*p2p4/mz**2*mup**2*mmo**4-4*p2p5/mz**2*mup**2*mmo**4-8*p3p4/mz*
     &   *4*mup**4*mmo**4+2*p3p4*mup**2*mmo**2+8*p4p5/mz**4*mup**4*mmo**4-
     &   2*p4p5*mup**2*mmo**2)
     &   +a1sprps*iz3mo*iz4mo*betasprmomo*chizpsc/ps**2/(s-mup**2)*a1z/pi*
     &   alpha**3*qmo**2/s*(s-spr)*(16*p1p2*p3p4/mz**4*mup**2*mmo**4-16*p1
     &   p2*p3p4**2/mz**4*mup**2*mmo**2-8*p1p3*p3p4/mz**2*mup**2*mmo**2-8*
     &   p1p4*p3p4/mz**2*mup**2*mmo**2+8*p1p5*p3p4/mz**2*mup**2*mmo**2+8*p
     &   2p3*p3p4/mz**2*mup**2*mmo**2+8*p2p4*p3p4/mz**2*mup**2*mmo**2-8*p2
     &   p5*p3p4/mz**2*mup**2*mmo**2+16*p3p4/mz**4*mup**4*mmo**4+8*p3p4*mu
     &   p**2*mmo**2-16*p3p4**2/mz**4*mup**4*mmo**2+4*p3p4**2*mup**2)
     &   +a1sprps*iz3mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2*qmo**
     &   2/s/spr*(s-spr)*(1d0/2*p1p2*mmo**2+1d0/4*p1p5*mmo**2-1d0/4*p2p5*m
     &   mo**2+1d0/2*p4p5/mz**2*mup**2*mmo**2)
     &   +a1sprps*iz3mo*betasprmomo*chizpsc/ps**2/(s-mup**2)*a1z/pi*alpha*
     &   *3*qmo**2/s*(s-spr)*(-4/mz**4*mup**4*mmo**4+mup**2*mmo**2-8*p1p2*
     &   p3p4/mz**4*mup**2*mmo**2+4*p1p2*p4p5/mz**4*mup**2*mmo**2-4*p1p2/m
     &   z**4*mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**2-4*p2p5/mz**2*mup**2
     &   *mmo**2-8*p3p4/mz**4*mup**4*mmo**2+2*p3p4*mup**2+4*p4p5/mz**4*mup
     &   **4*mmo**2-p4p5*mup**2)
     &   +a1sprps*iz3mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3
     &   *qup*qmo/s/spr*(s-spr)*(2*p1p3*p3p4/mz**4*mup**2*mmo**2-p1p3*p4p5
     &   /mz**4*mup**2*mmo**2-2*p1p3/mz**4*mup**2*mmo**4-p1p3/mz**2*mup**2
     &   *mmo**2+2*p2p3*p3p4/mz**4*mup**2*mmo**2-p2p3*p4p5/mz**4*mup**2*mm
     &   o**2-2*p2p3/mz**4*mup**2*mmo**4-p2p3/mz**2*mup**2*mmo**2)
     &   +a1sprps*iz4mo**2*betasprmomo*chizpsc/ps**2/(s-mup**2)*a1z/pi*alp
     &   ha**3*qmo**2/s*(s-spr)*(8/mz**4*mup**4*mmo**6+4*mup**2*mmo**4-8*p
     &   1p2*p3p4/mz**4*mup**2*mmo**4+8*p1p2*p3p5/mz**4*mup**2*mmo**4+8*p1
     &   p2/mz**4*mup**2*mmo**6-4*p1p3/mz**2*mup**2*mmo**4-4*p1p4/mz**2*mu
     &   p**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**4+4*p2p3/mz**2*mup**2*mmo**4
     &   +4*p2p4/mz**2*mup**2*mmo**4-4*p2p5/mz**2*mup**2*mmo**4-8*p3p4/mz*
     &   *4*mup**4*mmo**4+2*p3p4*mup**2*mmo**2+8*p3p5/mz**4*mup**4*mmo**4-
     &   2*p3p5*mup**2*mmo**2)
     &   +a1sprps*iz4mo*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2*qmo**
     &   2/s/spr*(s-spr)*(1d0/2*p1p2*mmo**2+1d0/4*p1p5*mmo**2-1d0/4*p2p5*m
     &   mo**2+1d0/2*p3p5/mz**2*mup**2*mmo**2)
     &   +a1sprps*iz4mo*betasprmomo*chizpsc/ps**2/(s-mup**2)*a1z/pi*alpha*
     &   *3*qmo**2/s*(s-spr)*(-4/mz**4*mup**4*mmo**4+mup**2*mmo**2-8*p1p2*
     &   p3p4/mz**4*mup**2*mmo**2+4*p1p2*p3p5/mz**4*mup**2*mmo**2-4*p1p2/m
     &   z**4*mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**2-4*p2p5/mz**2*mup**2
     &   *mmo**2-8*p3p4/mz**4*mup**4*mmo**2+2*p3p4*mup**2+4*p3p5/mz**4*mup
     &   **4*mmo**2-p3p5*mup**2)
     &   +a1sprps*iz4mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3
     &   *qup*qmo/s/spr*(s-spr)*(-2*p1p4*p3p4/mz**4*mup**2*mmo**2+p1p4*p3p
     &   5/mz**4*mup**2*mmo**2+2*p1p4/mz**4*mup**2*mmo**4+p1p4/mz**2*mup**
     &   2*mmo**2-2*p2p4*p3p4/mz**4*mup**2*mmo**2+p2p4*p3p5/mz**4*mup**2*m
     &   mo**2+2*p2p4/mz**4*mup**2*mmo**4+p2p4/mz**2*mup**2*mmo**2)
     &   +a1sprps*betasprmomo/ps/(s-mup**2)/pi*alpha**3*qup**2*qmo**2/s/sp
     &   r*(s-spr)*(-1d0/2/mz**2*mup**2*mmo**2)
     &   +a1sprps*betasprmomo*chizpsc/ps**2/(s-mup**2)*a1z/pi*alpha**3*qmo
     &   **2/s*(s-spr)*(-4/mz**4*mup**4*mmo**2-4*p1p2/mz**4*mup**2*mmo**2)
     &
     &   +a1sprps*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*qup*q
     &   mo/s/spr*(s-spr)*(1d0/2*p1p3/mz**4*mup**2*mmo**2-1d0/2*p1p4/mz**4
     &   *mup**2*mmo**2+1d0/2*p2p3/mz**4*mup**2*mmo**2-1d0/2*p2p4/mz**4*mu
     &   p**2*mmo**2)
     &   +iz1up**2*betasprmomo*chizspr*chizsprc/(s-mup**2)/pi*alpha**3*qup
     &   **2/s/spr**2*(s-spr)*(-4*aup**2*vmo**2*mup**4*mmo**2+2*p3p4*aup**
     &   2*vmo**2*mup**4)
     &   +iz1up**2*betasprmomo*chizspr*chizsprc/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup**2/s/spr**2*(s-spr)*(8/mz**4*mup**6*mmo**4+4*mup**4*mmo**
     &   2-8*p1p2*p3p4/mz**4*mup**4*mmo**2+8*p1p2/mz**4*mup**4*mmo**4-4*p1
     &   p3/mz**2*mup**4*mmo**2-4*p1p4/mz**2*mup**4*mmo**2+4*p2p3/mz**2*mu
     &   p**4*mmo**2+4*p2p4/mz**2*mup**4*mmo**2+8*p2p5*p3p4/mz**4*mup**4*m
     &   mo**2-8*p2p5/mz**4*mup**4*mmo**4-8*p3p4/mz**4*mup**6*mmo**2+2*p3p
     &   4*mup**4+4*p3p5/mz**2*mup**4*mmo**2+4*p4p5/mz**2*mup**4*mmo**2)
     &   +iz1up*iz2up*betasprmomo*chizspr*chizsprc/(s-mup**2)/pi*alpha**3*
     &   qup**2/s/spr**2*(s-spr)*(4*p1p2*p3p4*aup**2*vmo**2*mup**2-8*p1p2*
     &   aup**2*vmo**2*mup**2*mmo**2+4*p3p5*p4p5*aup**2*vmo**2*mup**2)
     &   +iz1up*iz2up*betasprmomo*chizspr*chizsprc/(s-mup**2)*a1z**2/pi*al
     &   pha**3*qup**2/s/spr**2*(s-spr)*(-8*p1p2*p1p3/mz**2*mup**2*mmo**2-
     &   8*p1p2*p1p4/mz**2*mup**2*mmo**2+8*p1p2*p2p3/mz**2*mup**2*mmo**2+8
     &   *p1p2*p2p4/mz**2*mup**2*mmo**2-16*p1p2*p3p4/mz**4*mup**4*mmo**2+4
     &   *p1p2*p3p4*mup**2+8*p1p2*p3p5/mz**2*mup**2*mmo**2+8*p1p2*p4p5/mz*
     &   *2*mup**2*mmo**2+16*p1p2/mz**4*mup**4*mmo**4+8*p1p2*mup**2*mmo**2
     &   -16*p1p2**2*p3p4/mz**4*mup**2*mmo**2+16*p1p2**2/mz**4*mup**2*mmo*
     &   *4+4*p3p5*p4p5*mup**2)
     &   +iz1up*iz3mo*betasprmomo*chizps*chizsprc/ps/(s-mup**2)/pi*alpha**
     &   3*qup*qmo/s/spr*(s-spr)*(2*p1p3*p3p4*aup**2*vmo**2*mup**2-p1p3*p4
     &   p5*aup**2*vmo**2*mup**2-4*p1p3*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz1up*iz3mo*betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qu
     &   p**2*qmo**2/s/spr*(s-spr)*(p2p5*p4p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz3mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)/pi*alpha**
     &   3*qup*qmo/s/spr*(s-spr)*(2*p1p3*p3p4*aup**2*vmo**2*mup**2-p1p3*p4
     &   p5*aup**2*vmo**2*mup**2-4*p1p3*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz1up*iz3mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*
     &   alpha**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p1p3*p3p4/mz**4*mup**2*mm
     &   o**2+4*p1p2*p1p3*p4p5/mz**4*mup**2*mmo**2+8*p1p2*p1p3/mz**4*mup**
     &   2*mmo**4-4*p1p3*p1p4/mz**2*mup**2*mmo**2+4*p1p3*p2p3/mz**2*mup**2
     &   *mmo**2+4*p1p3*p2p4/mz**2*mup**2*mmo**2+4*p1p3*p2p5*p3p4/mz**4*mu
     &   p**2*mmo**2-2*p1p3*p2p5*p4p5/mz**4*mup**2*mmo**2-4*p1p3*p2p5/mz**
     &   4*mup**2*mmo**4-2*p1p3*p2p5/mz**2*mup**2*mmo**2-8*p1p3*p3p4/mz**4
     &   *mup**4*mmo**2+2*p1p3*p3p4*mup**2+4*p1p3*p4p5/mz**4*mup**4*mmo**2
     &   +2*p1p3*p4p5/mz**2*mup**2*mmo**2-p1p3*p4p5*mup**2+8*p1p3/mz**4*mu
     &   p**4*mmo**4+4*p1p3*mup**2*mmo**2-4*p1p3**2/mz**2*mup**2*mmo**2-2*
     &   p2p5*p4p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz3mo*betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p1p3*p3p4/mz**4*mup**2*m
     &   mo**2+4*p1p2*p1p3*p4p5/mz**4*mup**2*mmo**2+8*p1p2*p1p3/mz**4*mup*
     &   *2*mmo**4-4*p1p3*p1p4/mz**2*mup**2*mmo**2+4*p1p3*p2p3/mz**2*mup**
     &   2*mmo**2+4*p1p3*p2p4/mz**2*mup**2*mmo**2+4*p1p3*p2p5*p3p4/mz**4*m
     &   up**2*mmo**2-2*p1p3*p2p5*p4p5/mz**4*mup**2*mmo**2-4*p1p3*p2p5/mz*
     &   *4*mup**2*mmo**4-2*p1p3*p2p5/mz**2*mup**2*mmo**2-8*p1p3*p3p4/mz**
     &   4*mup**4*mmo**2+2*p1p3*p3p4*mup**2+4*p1p3*p4p5/mz**4*mup**4*mmo**
     &   2+2*p1p3*p4p5/mz**2*mup**2*mmo**2-p1p3*p4p5*mup**2+8*p1p3/mz**4*m
     &   up**4*mmo**4+4*p1p3*mup**2*mmo**2-4*p1p3**2/mz**2*mup**2*mmo**2-2
     &   *p2p5*p4p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz3mo*betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p1p3*p3p4/mz**4*mup**2*mm
     &   o**2-4*p1p2*p1p3*p4p5/mz**4*mup**2*mmo**2-8*p1p2*p1p3/mz**4*mup**
     &   2*mmo**4+4*p1p3*p1p4/mz**2*mup**2*mmo**2-4*p1p3*p2p3/mz**2*mup**2
     &   *mmo**2-4*p1p3*p2p4/mz**2*mup**2*mmo**2-4*p1p3*p2p5*p3p4/mz**4*mu
     &   p**2*mmo**2+2*p1p3*p2p5*p4p5/mz**4*mup**2*mmo**2+4*p1p3*p2p5/mz**
     &   4*mup**2*mmo**4+2*p1p3*p2p5/mz**2*mup**2*mmo**2+8*p1p3*p3p4/mz**4
     &   *mup**4*mmo**2-2*p1p3*p3p4*mup**2-4*p1p3*p4p5/mz**4*mup**4*mmo**2
     &   -2*p1p3*p4p5/mz**2*mup**2*mmo**2+p1p3*p4p5*mup**2-8*p1p3/mz**4*mu
     &   p**4*mmo**4-4*p1p3*mup**2*mmo**2+4*p1p3**2/mz**2*mup**2*mmo**2+2*
     &   p2p5*p4p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz3mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*q
     &   up**2*qmo**2/s/spr*(s-spr)*(p2p5*p4p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz3mo*betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alph
     &   a**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p1p3*p3p4/mz**4*mup**2*mmo**2
     &   +4*p1p2*p1p3*p4p5/mz**4*mup**2*mmo**2+8*p1p2*p1p3/mz**4*mup**2*mm
     &   o**4-4*p1p3*p1p4/mz**2*mup**2*mmo**2+4*p1p3*p2p3/mz**2*mup**2*mmo
     &   **2+4*p1p3*p2p4/mz**2*mup**2*mmo**2+4*p1p3*p2p5*p3p4/mz**4*mup**2
     &   *mmo**2-2*p1p3*p2p5*p4p5/mz**4*mup**2*mmo**2-4*p1p3*p2p5/mz**4*mu
     &   p**2*mmo**4-2*p1p3*p2p5/mz**2*mup**2*mmo**2-8*p1p3*p3p4/mz**4*mup
     &   **4*mmo**2+2*p1p3*p3p4*mup**2+4*p1p3*p4p5/mz**4*mup**4*mmo**2+2*p
     &   1p3*p4p5/mz**2*mup**2*mmo**2-p1p3*p4p5*mup**2+8*p1p3/mz**4*mup**4
     &   *mmo**4+4*p1p3*mup**2*mmo**2-4*p1p3**2/mz**2*mup**2*mmo**2-2*p2p5
     &   *p4p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz4mo*betasprmomo*chizps*chizsprc/ps/(s-mup**2)/pi*alpha**
     &   3*qup*qmo/s/spr*(s-spr)*(-2*p1p4*p3p4*aup**2*vmo**2*mup**2+p1p4*p
     &   3p5*aup**2*vmo**2*mup**2+4*p1p4*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz1up*iz4mo*betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qu
     &   p**2*qmo**2/s/spr*(s-spr)*(p2p5*p3p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz4mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)/pi*alpha**
     &   3*qup*qmo/s/spr*(s-spr)*(-2*p1p4*p3p4*aup**2*vmo**2*mup**2+p1p4*p
     &   3p5*aup**2*vmo**2*mup**2+4*p1p4*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz1up*iz4mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*
     &   alpha**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p1p4*p3p4/mz**4*mup**2*mmo
     &   **2-4*p1p2*p1p4*p3p5/mz**4*mup**2*mmo**2-8*p1p2*p1p4/mz**4*mup**2
     &   *mmo**4+4*p1p3*p1p4/mz**2*mup**2*mmo**2-4*p1p4*p2p3/mz**2*mup**2*
     &   mmo**2-4*p1p4*p2p4/mz**2*mup**2*mmo**2-4*p1p4*p2p5*p3p4/mz**4*mup
     &   **2*mmo**2+2*p1p4*p2p5*p3p5/mz**4*mup**2*mmo**2+4*p1p4*p2p5/mz**4
     &   *mup**2*mmo**4+2*p1p4*p2p5/mz**2*mup**2*mmo**2+8*p1p4*p3p4/mz**4*
     &   mup**4*mmo**2-2*p1p4*p3p4*mup**2-4*p1p4*p3p5/mz**4*mup**4*mmo**2-
     &   2*p1p4*p3p5/mz**2*mup**2*mmo**2+p1p4*p3p5*mup**2-8*p1p4/mz**4*mup
     &   **4*mmo**4-4*p1p4*mup**2*mmo**2+4*p1p4**2/mz**2*mup**2*mmo**2+2*p
     &   2p5*p3p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz4mo*betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p1p4*p3p4/mz**4*mup**2*mm
     &   o**2-4*p1p2*p1p4*p3p5/mz**4*mup**2*mmo**2-8*p1p2*p1p4/mz**4*mup**
     &   2*mmo**4+4*p1p3*p1p4/mz**2*mup**2*mmo**2-4*p1p4*p2p3/mz**2*mup**2
     &   *mmo**2-4*p1p4*p2p4/mz**2*mup**2*mmo**2-4*p1p4*p2p5*p3p4/mz**4*mu
     &   p**2*mmo**2+2*p1p4*p2p5*p3p5/mz**4*mup**2*mmo**2+4*p1p4*p2p5/mz**
     &   4*mup**2*mmo**4+2*p1p4*p2p5/mz**2*mup**2*mmo**2+8*p1p4*p3p4/mz**4
     &   *mup**4*mmo**2-2*p1p4*p3p4*mup**2-4*p1p4*p3p5/mz**4*mup**4*mmo**2
     &   -2*p1p4*p3p5/mz**2*mup**2*mmo**2+p1p4*p3p5*mup**2-8*p1p4/mz**4*mu
     &   p**4*mmo**4-4*p1p4*mup**2*mmo**2+4*p1p4**2/mz**2*mup**2*mmo**2+2*
     &   p2p5*p3p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz4mo*betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p1p4*p3p4/mz**4*mup**2*m
     &   mo**2+4*p1p2*p1p4*p3p5/mz**4*mup**2*mmo**2+8*p1p2*p1p4/mz**4*mup*
     &   *2*mmo**4-4*p1p3*p1p4/mz**2*mup**2*mmo**2+4*p1p4*p2p3/mz**2*mup**
     &   2*mmo**2+4*p1p4*p2p4/mz**2*mup**2*mmo**2+4*p1p4*p2p5*p3p4/mz**4*m
     &   up**2*mmo**2-2*p1p4*p2p5*p3p5/mz**4*mup**2*mmo**2-4*p1p4*p2p5/mz*
     &   *4*mup**2*mmo**4-2*p1p4*p2p5/mz**2*mup**2*mmo**2-8*p1p4*p3p4/mz**
     &   4*mup**4*mmo**2+2*p1p4*p3p4*mup**2+4*p1p4*p3p5/mz**4*mup**4*mmo**
     &   2+2*p1p4*p3p5/mz**2*mup**2*mmo**2-p1p4*p3p5*mup**2+8*p1p4/mz**4*m
     &   up**4*mmo**4+4*p1p4*mup**2*mmo**2-4*p1p4**2/mz**2*mup**2*mmo**2-2
     &   *p2p5*p3p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz4mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*q
     &   up**2*qmo**2/s/spr*(s-spr)*(p2p5*p3p5/mz**2*mup**2*mmo**2)
     &   +iz1up*iz4mo*betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alph
     &   a**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p1p4*p3p4/mz**4*mup**2*mmo**2-
     &   4*p1p2*p1p4*p3p5/mz**4*mup**2*mmo**2-8*p1p2*p1p4/mz**4*mup**2*mmo
     &   **4+4*p1p3*p1p4/mz**2*mup**2*mmo**2-4*p1p4*p2p3/mz**2*mup**2*mmo*
     &   *2-4*p1p4*p2p4/mz**2*mup**2*mmo**2-4*p1p4*p2p5*p3p4/mz**4*mup**2*
     &   mmo**2+2*p1p4*p2p5*p3p5/mz**4*mup**2*mmo**2+4*p1p4*p2p5/mz**4*mup
     &   **2*mmo**4+2*p1p4*p2p5/mz**2*mup**2*mmo**2+8*p1p4*p3p4/mz**4*mup*
     &   *4*mmo**2-2*p1p4*p3p4*mup**2-4*p1p4*p3p5/mz**4*mup**4*mmo**2-2*p1
     &   p4*p3p5/mz**2*mup**2*mmo**2+p1p4*p3p5*mup**2-8*p1p4/mz**4*mup**4*
     &   mmo**4-4*p1p4*mup**2*mmo**2+4*p1p4**2/mz**2*mup**2*mmo**2+2*p2p5*
     &   p3p5/mz**2*mup**2*mmo**2)
     &   +iz1up*betasprmomo*chizps*chizsprc/ps/(s-mup**2)/pi*alpha**3*qup*
     &   qmo/s/spr*(s-spr)*(1d0/2*p1p3*aup**2*vmo**2*mup**2-1d0/2*p1p4*aup
     &   **2*vmo**2*mup**2+1d0/2*p3p5*aup**2*vmo**2*mup**2-1d0/2*p4p5*aup*
     &   *2*vmo**2*mup**2)
     &   +iz1up*betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*q
     &   mo**2/s/spr*(s-spr)*(-p2p5/mz**2*mup**2*mmo**2)
     &   +iz1up*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)/pi*alpha**3*qup*
     &   qmo/s/spr*(s-spr)*(1d0/2*p1p3*aup**2*vmo**2*mup**2-1d0/2*p1p4*aup
     &   **2*vmo**2*mup**2+1d0/2*p3p5*aup**2*vmo**2*mup**2-1d0/2*p4p5*aup*
     &   *2*vmo**2*mup**2)
     &   +iz1up*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*alpha*
     &   *3*qup*qmo/s/spr*(s-spr)*(-2*p1p2*p1p3/mz**4*mup**2*mmo**2+2*p1p2
     &   *p1p4/mz**4*mup**2*mmo**2+p1p3*p2p5/mz**4*mup**2*mmo**2-2*p1p3/mz
     &   **4*mup**4*mmo**2-p1p3/mz**2*mup**2*mmo**2+1d0/2*p1p3*mup**2-p1p4
     &   *p2p5/mz**4*mup**2*mmo**2+2*p1p4/mz**4*mup**4*mmo**2+p1p4/mz**2*m
     &   up**2*mmo**2-1d0/2*p1p4*mup**2+1d0/2*p3p5*mup**2-1d0/2*p4p5*mup**
     &   2)
     &   +iz1up*betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup*qmo/s/spr*(s-spr)*(-2*p1p2*p1p3/mz**4*mup**2*mmo**2+2*p1p
     &   2*p1p4/mz**4*mup**2*mmo**2+p1p3*p2p5/mz**4*mup**2*mmo**2-2*p1p3/m
     &   z**4*mup**4*mmo**2-p1p3/mz**2*mup**2*mmo**2+1d0/2*p1p3*mup**2-p1p
     &   4*p2p5/mz**4*mup**2*mmo**2+2*p1p4/mz**4*mup**4*mmo**2+p1p4/mz**2*
     &   mup**2*mmo**2-1d0/2*p1p4*mup**2+1d0/2*p3p5*mup**2-1d0/2*p4p5*mup*
     &   *2)
     &   +iz1up*betasprmomo*chizspr*chizsprc/(s-mup**2)*a1z**2/pi*alpha**3
     &   *qup**2/s/spr**2*(s-spr)*(-4/mz**4*mup**4*mmo**4-8*p1p2*p3p4/mz**
     &   4*mup**2*mmo**2+8*p1p2/mz**4*mup**2*mmo**4+4*p2p5*p3p4/mz**4*mup*
     &   *2*mmo**2-4*p2p5/mz**4*mup**2*mmo**4+4*p3p4/mz**4*mup**4*mmo**2+4
     &   *p3p5/mz**2*mup**2*mmo**2+4*p4p5/mz**2*mup**2*mmo**2)
     &   +iz1up*betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup*qmo/s/spr*(s-spr)*(2*p1p2*p1p3/mz**4*mup**2*mmo**2-2*p1p2
     &   *p1p4/mz**4*mup**2*mmo**2-p1p3*p2p5/mz**4*mup**2*mmo**2+2*p1p3/mz
     &   **4*mup**4*mmo**2+p1p3/mz**2*mup**2*mmo**2-1d0/2*p1p3*mup**2+p1p4
     &   *p2p5/mz**4*mup**2*mmo**2-2*p1p4/mz**4*mup**4*mmo**2-p1p4/mz**2*m
     &   up**2*mmo**2+1d0/2*p1p4*mup**2-1d0/2*p3p5*mup**2+1d0/2*p4p5*mup**
     &   2)
     &   +iz1up*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*
     &   qmo**2/s/spr*(s-spr)*(-p2p5/mz**2*mup**2*mmo**2)
     &   +iz1up*betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alpha**3*q
     &   up*qmo/s/spr*(s-spr)*(-2*p1p2*p1p3/mz**4*mup**2*mmo**2+2*p1p2*p1p
     &   4/mz**4*mup**2*mmo**2+p1p3*p2p5/mz**4*mup**2*mmo**2-2*p1p3/mz**4*
     &   mup**4*mmo**2-p1p3/mz**2*mup**2*mmo**2+1d0/2*p1p3*mup**2-p1p4*p2p
     &   5/mz**4*mup**2*mmo**2+2*p1p4/mz**4*mup**4*mmo**2+p1p4/mz**2*mup**
     &   2*mmo**2-1d0/2*p1p4*mup**2+1d0/2*p3p5*mup**2-1d0/2*p4p5*mup**2)
     &   +iz2up**2*betasprmomo*chizspr*chizsprc/(s-mup**2)/pi*alpha**3*qup
     &   **2/s/spr**2*(s-spr)*(-4*aup**2*vmo**2*mup**4*mmo**2+2*p3p4*aup**
     &   2*vmo**2*mup**4)
     &   +iz2up**2*betasprmomo*chizspr*chizsprc/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup**2/s/spr**2*(s-spr)*(8/mz**4*mup**6*mmo**4+4*mup**4*mmo**
     &   2-8*p1p2*p3p4/mz**4*mup**4*mmo**2+8*p1p2/mz**4*mup**4*mmo**4-4*p1
     &   p3/mz**2*mup**4*mmo**2-4*p1p4/mz**2*mup**4*mmo**2-8*p1p5*p3p4/mz*
     &   *4*mup**4*mmo**2+8*p1p5/mz**4*mup**4*mmo**4+4*p2p3/mz**2*mup**4*m
     &   mo**2+4*p2p4/mz**2*mup**4*mmo**2-8*p3p4/mz**4*mup**6*mmo**2+2*p3p
     &   4*mup**4+4*p3p5/mz**2*mup**4*mmo**2+4*p4p5/mz**2*mup**4*mmo**2)
     &   +iz2up*iz3mo*betasprmomo*chizps*chizsprc/ps/(s-mup**2)/pi*alpha**
     &   3*qup*qmo/s/spr*(s-spr)*(-2*p2p3*p3p4*aup**2*vmo**2*mup**2+p2p3*p
     &   4p5*aup**2*vmo**2*mup**2+4*p2p3*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz2up*iz3mo*betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qu
     &   p**2*qmo**2/s/spr*(s-spr)*(p1p5*p4p5/mz**2*mup**2*mmo**2)
     &   +iz2up*iz3mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)/pi*alpha**
     &   3*qup*qmo/s/spr*(s-spr)*(-2*p2p3*p3p4*aup**2*vmo**2*mup**2+p2p3*p
     &   4p5*aup**2*vmo**2*mup**2+4*p2p3*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz2up*iz3mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*
     &   alpha**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p2p3*p3p4/mz**4*mup**2*mmo
     &   **2-4*p1p2*p2p3*p4p5/mz**4*mup**2*mmo**2-8*p1p2*p2p3/mz**4*mup**2
     &   *mmo**4+4*p1p3*p2p3/mz**2*mup**2*mmo**2+4*p1p4*p2p3/mz**2*mup**2*
     &   mmo**2+4*p1p5*p2p3*p3p4/mz**4*mup**2*mmo**2-2*p1p5*p2p3*p4p5/mz**
     &   4*mup**2*mmo**2-4*p1p5*p2p3/mz**4*mup**2*mmo**4-2*p1p5*p2p3/mz**2
     &   *mup**2*mmo**2+2*p1p5*p4p5/mz**2*mup**2*mmo**2-4*p2p3*p2p4/mz**2*
     &   mup**2*mmo**2+8*p2p3*p3p4/mz**4*mup**4*mmo**2-2*p2p3*p3p4*mup**2-
     &   4*p2p3*p4p5/mz**4*mup**4*mmo**2-2*p2p3*p4p5/mz**2*mup**2*mmo**2+p
     &   2p3*p4p5*mup**2-8*p2p3/mz**4*mup**4*mmo**4-4*p2p3*mup**2*mmo**2-4
     &   *p2p3**2/mz**2*mup**2*mmo**2)
     &   +iz2up*iz3mo*betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p2p3*p3p4/mz**4*mup**2*mm
     &   o**2-4*p1p2*p2p3*p4p5/mz**4*mup**2*mmo**2-8*p1p2*p2p3/mz**4*mup**
     &   2*mmo**4+4*p1p3*p2p3/mz**2*mup**2*mmo**2+4*p1p4*p2p3/mz**2*mup**2
     &   *mmo**2+4*p1p5*p2p3*p3p4/mz**4*mup**2*mmo**2-2*p1p5*p2p3*p4p5/mz*
     &   *4*mup**2*mmo**2-4*p1p5*p2p3/mz**4*mup**2*mmo**4-2*p1p5*p2p3/mz**
     &   2*mup**2*mmo**2+2*p1p5*p4p5/mz**2*mup**2*mmo**2-4*p2p3*p2p4/mz**2
     &   *mup**2*mmo**2+8*p2p3*p3p4/mz**4*mup**4*mmo**2-2*p2p3*p3p4*mup**2
     &   -4*p2p3*p4p5/mz**4*mup**4*mmo**2-2*p2p3*p4p5/mz**2*mup**2*mmo**2+
     &   p2p3*p4p5*mup**2-8*p2p3/mz**4*mup**4*mmo**4-4*p2p3*mup**2*mmo**2-
     &   4*p2p3**2/mz**2*mup**2*mmo**2)
     &   +iz2up*iz3mo*betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p2p3*p3p4/mz**4*mup**2*m
     &   mo**2+4*p1p2*p2p3*p4p5/mz**4*mup**2*mmo**2+8*p1p2*p2p3/mz**4*mup*
     &   *2*mmo**4-4*p1p3*p2p3/mz**2*mup**2*mmo**2-4*p1p4*p2p3/mz**2*mup**
     &   2*mmo**2-4*p1p5*p2p3*p3p4/mz**4*mup**2*mmo**2+2*p1p5*p2p3*p4p5/mz
     &   **4*mup**2*mmo**2+4*p1p5*p2p3/mz**4*mup**2*mmo**4+2*p1p5*p2p3/mz*
     &   *2*mup**2*mmo**2-2*p1p5*p4p5/mz**2*mup**2*mmo**2+4*p2p3*p2p4/mz**
     &   2*mup**2*mmo**2-8*p2p3*p3p4/mz**4*mup**4*mmo**2+2*p2p3*p3p4*mup**
     &   2+4*p2p3*p4p5/mz**4*mup**4*mmo**2+2*p2p3*p4p5/mz**2*mup**2*mmo**2
     &   -p2p3*p4p5*mup**2+8*p2p3/mz**4*mup**4*mmo**4+4*p2p3*mup**2*mmo**2
     &   +4*p2p3**2/mz**2*mup**2*mmo**2)
     &   +iz2up*iz3mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*q
     &   up**2*qmo**2/s/spr*(s-spr)*(p1p5*p4p5/mz**2*mup**2*mmo**2)
     &   +iz2up*iz3mo*betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alph
     &   a**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p2p3*p3p4/mz**4*mup**2*mmo**2-
     &   4*p1p2*p2p3*p4p5/mz**4*mup**2*mmo**2-8*p1p2*p2p3/mz**4*mup**2*mmo
     &   **4+4*p1p3*p2p3/mz**2*mup**2*mmo**2+4*p1p4*p2p3/mz**2*mup**2*mmo*
     &   *2+4*p1p5*p2p3*p3p4/mz**4*mup**2*mmo**2-2*p1p5*p2p3*p4p5/mz**4*mu
     &   p**2*mmo**2-4*p1p5*p2p3/mz**4*mup**2*mmo**4-2*p1p5*p2p3/mz**2*mup
     &   **2*mmo**2+2*p1p5*p4p5/mz**2*mup**2*mmo**2-4*p2p3*p2p4/mz**2*mup*
     &   *2*mmo**2+8*p2p3*p3p4/mz**4*mup**4*mmo**2-2*p2p3*p3p4*mup**2-4*p2
     &   p3*p4p5/mz**4*mup**4*mmo**2-2*p2p3*p4p5/mz**2*mup**2*mmo**2+p2p3*
     &   p4p5*mup**2-8*p2p3/mz**4*mup**4*mmo**4-4*p2p3*mup**2*mmo**2-4*p2p
     &   3**2/mz**2*mup**2*mmo**2)
     &   +iz2up*iz4mo*betasprmomo*chizps*chizsprc/ps/(s-mup**2)/pi*alpha**
     &   3*qup*qmo/s/spr*(s-spr)*(2*p2p4*p3p4*aup**2*vmo**2*mup**2-p2p4*p3
     &   p5*aup**2*vmo**2*mup**2-4*p2p4*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz2up*iz4mo*betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qu
     &   p**2*qmo**2/s/spr*(s-spr)*(p1p5*p3p5/mz**2*mup**2*mmo**2)
     &   +iz2up*iz4mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)/pi*alpha**
     &   3*qup*qmo/s/spr*(s-spr)*(2*p2p4*p3p4*aup**2*vmo**2*mup**2-p2p4*p3
     &   p5*aup**2*vmo**2*mup**2-4*p2p4*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz2up*iz4mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*
     &   alpha**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p2p4*p3p4/mz**4*mup**2*mm
     &   o**2+4*p1p2*p2p4*p3p5/mz**4*mup**2*mmo**2+8*p1p2*p2p4/mz**4*mup**
     &   2*mmo**4-4*p1p3*p2p4/mz**2*mup**2*mmo**2-4*p1p4*p2p4/mz**2*mup**2
     &   *mmo**2-4*p1p5*p2p4*p3p4/mz**4*mup**2*mmo**2+2*p1p5*p2p4*p3p5/mz*
     &   *4*mup**2*mmo**2+4*p1p5*p2p4/mz**4*mup**2*mmo**4+2*p1p5*p2p4/mz**
     &   2*mup**2*mmo**2-2*p1p5*p3p5/mz**2*mup**2*mmo**2+4*p2p3*p2p4/mz**2
     &   *mup**2*mmo**2-8*p2p4*p3p4/mz**4*mup**4*mmo**2+2*p2p4*p3p4*mup**2
     &   +4*p2p4*p3p5/mz**4*mup**4*mmo**2+2*p2p4*p3p5/mz**2*mup**2*mmo**2-
     &   p2p4*p3p5*mup**2+8*p2p4/mz**4*mup**4*mmo**4+4*p2p4*mup**2*mmo**2+
     &   4*p2p4**2/mz**2*mup**2*mmo**2)
     &   +iz2up*iz4mo*betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p2p4*p3p4/mz**4*mup**2*m
     &   mo**2+4*p1p2*p2p4*p3p5/mz**4*mup**2*mmo**2+8*p1p2*p2p4/mz**4*mup*
     &   *2*mmo**4-4*p1p3*p2p4/mz**2*mup**2*mmo**2-4*p1p4*p2p4/mz**2*mup**
     &   2*mmo**2-4*p1p5*p2p4*p3p4/mz**4*mup**2*mmo**2+2*p1p5*p2p4*p3p5/mz
     &   **4*mup**2*mmo**2+4*p1p5*p2p4/mz**4*mup**2*mmo**4+2*p1p5*p2p4/mz*
     &   *2*mup**2*mmo**2-2*p1p5*p3p5/mz**2*mup**2*mmo**2+4*p2p3*p2p4/mz**
     &   2*mup**2*mmo**2-8*p2p4*p3p4/mz**4*mup**4*mmo**2+2*p2p4*p3p4*mup**
     &   2+4*p2p4*p3p5/mz**4*mup**4*mmo**2+2*p2p4*p3p5/mz**2*mup**2*mmo**2
     &   -p2p4*p3p5*mup**2+8*p2p4/mz**4*mup**4*mmo**4+4*p2p4*mup**2*mmo**2
     &   +4*p2p4**2/mz**2*mup**2*mmo**2)
     &   +iz2up*iz4mo*betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qup*qmo/s/spr*(s-spr)*(8*p1p2*p2p4*p3p4/mz**4*mup**2*mm
     &   o**2-4*p1p2*p2p4*p3p5/mz**4*mup**2*mmo**2-8*p1p2*p2p4/mz**4*mup**
     &   2*mmo**4+4*p1p3*p2p4/mz**2*mup**2*mmo**2+4*p1p4*p2p4/mz**2*mup**2
     &   *mmo**2+4*p1p5*p2p4*p3p4/mz**4*mup**2*mmo**2-2*p1p5*p2p4*p3p5/mz*
     &   *4*mup**2*mmo**2-4*p1p5*p2p4/mz**4*mup**2*mmo**4-2*p1p5*p2p4/mz**
     &   2*mup**2*mmo**2+2*p1p5*p3p5/mz**2*mup**2*mmo**2-4*p2p3*p2p4/mz**2
     &   *mup**2*mmo**2+8*p2p4*p3p4/mz**4*mup**4*mmo**2-2*p2p4*p3p4*mup**2
     &   -4*p2p4*p3p5/mz**4*mup**4*mmo**2-2*p2p4*p3p5/mz**2*mup**2*mmo**2+
     &   p2p4*p3p5*mup**2-8*p2p4/mz**4*mup**4*mmo**4-4*p2p4*mup**2*mmo**2-
     &   4*p2p4**2/mz**2*mup**2*mmo**2)
     &   +iz2up*iz4mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*q
     &   up**2*qmo**2/s/spr*(s-spr)*(p1p5*p3p5/mz**2*mup**2*mmo**2)
     &   +iz2up*iz4mo*betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alph
     &   a**3*qup*qmo/s/spr*(s-spr)*(-8*p1p2*p2p4*p3p4/mz**4*mup**2*mmo**2
     &   +4*p1p2*p2p4*p3p5/mz**4*mup**2*mmo**2+8*p1p2*p2p4/mz**4*mup**2*mm
     &   o**4-4*p1p3*p2p4/mz**2*mup**2*mmo**2-4*p1p4*p2p4/mz**2*mup**2*mmo
     &   **2-4*p1p5*p2p4*p3p4/mz**4*mup**2*mmo**2+2*p1p5*p2p4*p3p5/mz**4*m
     &   up**2*mmo**2+4*p1p5*p2p4/mz**4*mup**2*mmo**4+2*p1p5*p2p4/mz**2*mu
     &   p**2*mmo**2-2*p1p5*p3p5/mz**2*mup**2*mmo**2+4*p2p3*p2p4/mz**2*mup
     &   **2*mmo**2-8*p2p4*p3p4/mz**4*mup**4*mmo**2+2*p2p4*p3p4*mup**2+4*p
     &   2p4*p3p5/mz**4*mup**4*mmo**2+2*p2p4*p3p5/mz**2*mup**2*mmo**2-p2p4
     &   *p3p5*mup**2+8*p2p4/mz**4*mup**4*mmo**4+4*p2p4*mup**2*mmo**2+4*p2
     &   p4**2/mz**2*mup**2*mmo**2)
     &   +iz2up*betasprmomo*chizps*chizsprc/ps/(s-mup**2)/pi*alpha**3*qup*
     &   qmo/s/spr*(s-spr)*(-1d0/2*p2p3*aup**2*vmo**2*mup**2+1d0/2*p2p4*au
     &   p**2*vmo**2*mup**2+1d0/2*p3p5*aup**2*vmo**2*mup**2-1d0/2*p4p5*aup
     &   **2*vmo**2*mup**2)
     &   +iz2up*betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*q
     &   mo**2/s/spr*(s-spr)*(-p1p5/mz**2*mup**2*mmo**2)
     &   +iz2up*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)/pi*alpha**3*qup*
     &   qmo/s/spr*(s-spr)*(-1d0/2*p2p3*aup**2*vmo**2*mup**2+1d0/2*p2p4*au
     &   p**2*vmo**2*mup**2+1d0/2*p3p5*aup**2*vmo**2*mup**2-1d0/2*p4p5*aup
     &   **2*vmo**2*mup**2)
     &   +iz2up*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*alpha*
     &   *3*qup*qmo/s/spr*(s-spr)*(2*p1p2*p2p3/mz**4*mup**2*mmo**2-2*p1p2*
     &   p2p4/mz**4*mup**2*mmo**2+p1p5*p2p3/mz**4*mup**2*mmo**2-p1p5*p2p4/
     &   mz**4*mup**2*mmo**2+2*p2p3/mz**4*mup**4*mmo**2+p2p3/mz**2*mup**2*
     &   mmo**2-1d0/2*p2p3*mup**2-2*p2p4/mz**4*mup**4*mmo**2-p2p4/mz**2*mu
     &   p**2*mmo**2+1d0/2*p2p4*mup**2+1d0/2*p3p5*mup**2-1d0/2*p4p5*mup**2
     &   )
     &   +iz2up*betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup*qmo/s/spr*(s-spr)*(2*p1p2*p2p3/mz**4*mup**2*mmo**2-2*p1p2
     &   *p2p4/mz**4*mup**2*mmo**2+p1p5*p2p3/mz**4*mup**2*mmo**2-p1p5*p2p4
     &   /mz**4*mup**2*mmo**2+2*p2p3/mz**4*mup**4*mmo**2+p2p3/mz**2*mup**2
     &   *mmo**2-1d0/2*p2p3*mup**2-2*p2p4/mz**4*mup**4*mmo**2-p2p4/mz**2*m
     &   up**2*mmo**2+1d0/2*p2p4*mup**2+1d0/2*p3p5*mup**2-1d0/2*p4p5*mup**
     &   2)
     &   +iz2up*betasprmomo*chizspr*chizsprc/(s-mup**2)*a1z**2/pi*alpha**3
     &   *qup**2/s/spr**2*(s-spr)*(4/mz**4*mup**4*mmo**4+8*p1p2*p3p4/mz**4
     &   *mup**2*mmo**2-8*p1p2/mz**4*mup**2*mmo**4+4*p1p5*p3p4/mz**4*mup**
     &   2*mmo**2-4*p1p5/mz**4*mup**2*mmo**4-4*p3p4/mz**4*mup**4*mmo**2-4*
     &   p3p5/mz**2*mup**2*mmo**2-4*p4p5/mz**2*mup**2*mmo**2)
     &   +iz2up*betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup*qmo/s/spr*(s-spr)*(-2*p1p2*p2p3/mz**4*mup**2*mmo**2+2*p1p
     &   2*p2p4/mz**4*mup**2*mmo**2-p1p5*p2p3/mz**4*mup**2*mmo**2+p1p5*p2p
     &   4/mz**4*mup**2*mmo**2-2*p2p3/mz**4*mup**4*mmo**2-p2p3/mz**2*mup**
     &   2*mmo**2+1d0/2*p2p3*mup**2+2*p2p4/mz**4*mup**4*mmo**2+p2p4/mz**2*
     &   mup**2*mmo**2-1d0/2*p2p4*mup**2-1d0/2*p3p5*mup**2+1d0/2*p4p5*mup*
     &   *2)
     &   +iz2up*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*
     &   qmo**2/s/spr*(s-spr)*(-p1p5/mz**2*mup**2*mmo**2)
     &   +iz2up*betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alpha**3*q
     &   up*qmo/s/spr*(s-spr)*(2*p1p2*p2p3/mz**4*mup**2*mmo**2-2*p1p2*p2p4
     &   /mz**4*mup**2*mmo**2+p1p5*p2p3/mz**4*mup**2*mmo**2-p1p5*p2p4/mz**
     &   4*mup**2*mmo**2+2*p2p3/mz**4*mup**4*mmo**2+p2p3/mz**2*mup**2*mmo*
     &   *2-1d0/2*p2p3*mup**2-2*p2p4/mz**4*mup**4*mmo**2-p2p4/mz**2*mup**2
     &   *mmo**2+1d0/2*p2p4*mup**2+1d0/2*p3p5*mup**2-1d0/2*p4p5*mup**2)
     &   +iz3mo**2*betasprmomo*chizps*chizpsc/ps**2/(s-mup**2)/pi*alpha**3
     &   *qmo**2/s*(s-spr)*(-4*aup**2*vmo**2*mup**2*mmo**4+2*p3p4*aup**2*v
     &   mo**2*mup**2*mmo**2-2*p4p5*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz3mo**2*betasprmomo*chizspr*chizpsc/ps**2/(s-mup**2)*a1z**2/pi*
     &   alpha**3*qmo**2/s*(s-spr)*(8/mz**4*mup**4*mmo**6+4*mup**2*mmo**4-
     &   8*p1p2*p3p4/mz**4*mup**2*mmo**4+8*p1p2*p4p5/mz**4*mup**2*mmo**4+8
     &   *p1p2/mz**4*mup**2*mmo**6-4*p1p3/mz**2*mup**2*mmo**4-4*p1p4/mz**2
     &   *mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**4+4*p2p3/mz**2*mup**2*mmo
     &   **4+4*p2p4/mz**2*mup**2*mmo**4-4*p2p5/mz**2*mup**2*mmo**4-8*p3p4/
     &   mz**4*mup**4*mmo**4+2*p3p4*mup**2*mmo**2+8*p4p5/mz**4*mup**4*mmo*
     &   *4-2*p4p5*mup**2*mmo**2)
     &   +iz3mo**2*betasprmomo*chizpsc**2/ps**2/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qmo**2/s*(s-spr)*(-8/mz**4*mup**4*mmo**6-4*mup**2*mmo**4+8*p1
     &   p2*p3p4/mz**4*mup**2*mmo**4-8*p1p2*p4p5/mz**4*mup**2*mmo**4-8*p1p
     &   2/mz**4*mup**2*mmo**6+4*p1p3/mz**2*mup**2*mmo**4+4*p1p4/mz**2*mup
     &   **2*mmo**4-4*p1p5/mz**2*mup**2*mmo**4-4*p2p3/mz**2*mup**2*mmo**4-
     &   4*p2p4/mz**2*mup**2*mmo**4+4*p2p5/mz**2*mup**2*mmo**4+8*p3p4/mz**
     &   4*mup**4*mmo**4-2*p3p4*mup**2*mmo**2-8*p4p5/mz**4*mup**4*mmo**4+2
     &   *p4p5*mup**2*mmo**2)
     &   +iz3mo**2*betasprmomo*chizpsc*chizsprc/ps**2/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qmo**2/s*(s-spr)*(8/mz**4*mup**4*mmo**6+4*mup**2*mmo**4
     &   -8*p1p2*p3p4/mz**4*mup**2*mmo**4+8*p1p2*p4p5/mz**4*mup**2*mmo**4+
     &   8*p1p2/mz**4*mup**2*mmo**6-4*p1p3/mz**2*mup**2*mmo**4-4*p1p4/mz**
     &   2*mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**4+4*p2p3/mz**2*mup**2*mm
     &   o**4+4*p2p4/mz**2*mup**2*mmo**4-4*p2p5/mz**2*mup**2*mmo**4-8*p3p4
     &   /mz**4*mup**4*mmo**4+2*p3p4*mup**2*mmo**2+8*p4p5/mz**4*mup**4*mmo
     &   **4-2*p4p5*mup**2*mmo**2)
     &   +iz3mo*iz4mo*betasprmomo*chizps*chizpsc/ps**2/(s-mup**2)/pi*alpha
     &   **3*qmo**2/s*(s-spr)*(-8*p3p4*aup**2*vmo**2*mup**2*mmo**2+4*p3p4*
     &   *2*aup**2*vmo**2*mup**2)
     &   +iz3mo*iz4mo*betasprmomo*chizspr*chizpsc/ps**2/(s-mup**2)*a1z**2/
     &   pi*alpha**3*qmo**2/s*(s-spr)*(16*p1p2*p3p4/mz**4*mup**2*mmo**4-16
     &   *p1p2*p3p4**2/mz**4*mup**2*mmo**2-8*p1p3*p3p4/mz**2*mup**2*mmo**2
     &   -8*p1p4*p3p4/mz**2*mup**2*mmo**2+8*p1p5*p3p4/mz**2*mup**2*mmo**2+
     &   8*p2p3*p3p4/mz**2*mup**2*mmo**2+8*p2p4*p3p4/mz**2*mup**2*mmo**2-8
     &   *p2p5*p3p4/mz**2*mup**2*mmo**2+16*p3p4/mz**4*mup**4*mmo**4+8*p3p4
     &   *mup**2*mmo**2-16*p3p4**2/mz**4*mup**4*mmo**2+4*p3p4**2*mup**2)
     &   +iz3mo*iz4mo*betasprmomo*chizpsc**2/ps**2/(s-mup**2)*a1z**2/pi*al
     &   pha**3*qmo**2/s*(s-spr)*(-16*p1p2*p3p4/mz**4*mup**2*mmo**4+16*p1p
     &   2*p3p4**2/mz**4*mup**2*mmo**2+8*p1p3*p3p4/mz**2*mup**2*mmo**2+8*p
     &   1p4*p3p4/mz**2*mup**2*mmo**2-8*p1p5*p3p4/mz**2*mup**2*mmo**2-8*p2
     &   p3*p3p4/mz**2*mup**2*mmo**2-8*p2p4*p3p4/mz**2*mup**2*mmo**2+8*p2p
     &   5*p3p4/mz**2*mup**2*mmo**2-16*p3p4/mz**4*mup**4*mmo**4-8*p3p4*mup
     &   **2*mmo**2+16*p3p4**2/mz**4*mup**4*mmo**2-4*p3p4**2*mup**2)
     &   +iz3mo*iz4mo*betasprmomo*chizpsc*chizsprc/ps**2/(s-mup**2)*a1z**2
     &   /pi*alpha**3*qmo**2/s*(s-spr)*(16*p1p2*p3p4/mz**4*mup**2*mmo**4-1
     &   6*p1p2*p3p4**2/mz**4*mup**2*mmo**2-8*p1p3*p3p4/mz**2*mup**2*mmo**
     &   2-8*p1p4*p3p4/mz**2*mup**2*mmo**2+8*p1p5*p3p4/mz**2*mup**2*mmo**2
     &   +8*p2p3*p3p4/mz**2*mup**2*mmo**2+8*p2p4*p3p4/mz**2*mup**2*mmo**2-
     &   8*p2p5*p3p4/mz**2*mup**2*mmo**2+16*p3p4/mz**4*mup**4*mmo**4+8*p3p
     &   4*mup**2*mmo**2-16*p3p4**2/mz**4*mup**4*mmo**2+4*p3p4**2*mup**2)
     &   +iz3mo*betasprmomo*chizps*chizpsc/ps**2/(s-mup**2)/pi*alpha**3*qm
     &   o**2/s*(s-spr)*(aup**2*vmo**2*mup**2*mmo**2+2*p3p4*aup**2*vmo**2*
     &   mup**2-p4p5*aup**2*vmo**2*mup**2)
     &   +iz3mo*betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*q
     &   mo**2/s/spr*(s-spr)*(p4p5/mz**2*mup**2*mmo**2)
     &   +iz3mo*betasprmomo*chizspr*chizpsc/ps**2/(s-mup**2)*a1z**2/pi*alp
     &   ha**3*qmo**2/s*(s-spr)*(-4/mz**4*mup**4*mmo**4+mup**2*mmo**2-8*p1
     &   p2*p3p4/mz**4*mup**2*mmo**2+4*p1p2*p4p5/mz**4*mup**2*mmo**2-4*p1p
     &   2/mz**4*mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**2-4*p2p5/mz**2*mup
     &   **2*mmo**2-8*p3p4/mz**4*mup**4*mmo**2+2*p3p4*mup**2+4*p4p5/mz**4*
     &   mup**4*mmo**2-p4p5*mup**2)
     &   +iz3mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*alpha*
     &   *3*qup*qmo/s/spr*(s-spr)*(2*p1p3*p3p4/mz**4*mup**2*mmo**2-p1p3*p4
     &   p5/mz**4*mup**2*mmo**2-2*p1p3/mz**4*mup**2*mmo**4-p1p3/mz**2*mup*
     &   *2*mmo**2+2*p2p3*p3p4/mz**4*mup**2*mmo**2-p2p3*p4p5/mz**4*mup**2*
     &   mmo**2-2*p2p3/mz**4*mup**2*mmo**4-p2p3/mz**2*mup**2*mmo**2)
     &   +iz3mo*betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup*qmo/s/spr*(s-spr)*(2*p1p3*p3p4/mz**4*mup**2*mmo**2-p1p3*p
     &   4p5/mz**4*mup**2*mmo**2-2*p1p3/mz**4*mup**2*mmo**4-p1p3/mz**2*mup
     &   **2*mmo**2+2*p2p3*p3p4/mz**4*mup**2*mmo**2-p2p3*p4p5/mz**4*mup**2
     &   *mmo**2-2*p2p3/mz**4*mup**2*mmo**4-p2p3/mz**2*mup**2*mmo**2)
     &   +iz3mo*betasprmomo*chizpsc**2/ps**2/(s-mup**2)*a1z**2/pi*alpha**3
     &   *qmo**2/s*(s-spr)*(4/mz**4*mup**4*mmo**4-mup**2*mmo**2+8*p1p2*p3p
     &   4/mz**4*mup**2*mmo**2-4*p1p2*p4p5/mz**4*mup**2*mmo**2+4*p1p2/mz**
     &   4*mup**2*mmo**4-4*p1p5/mz**2*mup**2*mmo**2+4*p2p5/mz**2*mup**2*mm
     &   o**2+8*p3p4/mz**4*mup**4*mmo**2-2*p3p4*mup**2-4*p4p5/mz**4*mup**4
     &   *mmo**2+p4p5*mup**2)
     &   +iz3mo*betasprmomo*chizpsc*chizsprc/ps**2/(s-mup**2)*a1z**2/pi*al
     &   pha**3*qmo**2/s*(s-spr)*(-4/mz**4*mup**4*mmo**4+mup**2*mmo**2-8*p
     &   1p2*p3p4/mz**4*mup**2*mmo**2+4*p1p2*p4p5/mz**4*mup**2*mmo**2-4*p1
     &   p2/mz**4*mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**2-4*p2p5/mz**2*mu
     &   p**2*mmo**2-8*p3p4/mz**4*mup**4*mmo**2+2*p3p4*mup**2+4*p4p5/mz**4
     &   *mup**4*mmo**2-p4p5*mup**2)
     &   +iz3mo*betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup*qmo/s/spr*(s-spr)*(-2*p1p3*p3p4/mz**4*mup**2*mmo**2+p1p3*
     &   p4p5/mz**4*mup**2*mmo**2+2*p1p3/mz**4*mup**2*mmo**4+p1p3/mz**2*mu
     &   p**2*mmo**2-2*p2p3*p3p4/mz**4*mup**2*mmo**2+p2p3*p4p5/mz**4*mup**
     &   2*mmo**2+2*p2p3/mz**4*mup**2*mmo**4+p2p3/mz**2*mup**2*mmo**2)
     &   +iz3mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*
     &   qmo**2/s/spr*(s-spr)*(p4p5/mz**2*mup**2*mmo**2)
     &   +iz3mo*betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alpha**3*q
     &   up*qmo/s/spr*(s-spr)*(2*p1p3*p3p4/mz**4*mup**2*mmo**2-p1p3*p4p5/m
     &   z**4*mup**2*mmo**2-2*p1p3/mz**4*mup**2*mmo**4-p1p3/mz**2*mup**2*m
     &   mo**2+2*p2p3*p3p4/mz**4*mup**2*mmo**2-p2p3*p4p5/mz**4*mup**2*mmo*
     &   *2-2*p2p3/mz**4*mup**2*mmo**4-p2p3/mz**2*mup**2*mmo**2)
     &   +iz4mo**2*betasprmomo*chizps*chizpsc/ps**2/(s-mup**2)/pi*alpha**3
     &   *qmo**2/s*(s-spr)*(-4*aup**2*vmo**2*mup**2*mmo**4+2*p3p4*aup**2*v
     &   mo**2*mup**2*mmo**2-2*p3p5*aup**2*vmo**2*mup**2*mmo**2)
     &   +iz4mo**2*betasprmomo*chizspr*chizpsc/ps**2/(s-mup**2)*a1z**2/pi*
     &   alpha**3*qmo**2/s*(s-spr)*(8/mz**4*mup**4*mmo**6+4*mup**2*mmo**4-
     &   8*p1p2*p3p4/mz**4*mup**2*mmo**4+8*p1p2*p3p5/mz**4*mup**2*mmo**4+8
     &   *p1p2/mz**4*mup**2*mmo**6-4*p1p3/mz**2*mup**2*mmo**4-4*p1p4/mz**2
     &   *mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**4+4*p2p3/mz**2*mup**2*mmo
     &   **4+4*p2p4/mz**2*mup**2*mmo**4-4*p2p5/mz**2*mup**2*mmo**4-8*p3p4/
     &   mz**4*mup**4*mmo**4+2*p3p4*mup**2*mmo**2+8*p3p5/mz**4*mup**4*mmo*
     &   *4-2*p3p5*mup**2*mmo**2)
     &   +iz4mo**2*betasprmomo*chizpsc**2/ps**2/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qmo**2/s*(s-spr)*(-8/mz**4*mup**4*mmo**6-4*mup**2*mmo**4+8*p1
     &   p2*p3p4/mz**4*mup**2*mmo**4-8*p1p2*p3p5/mz**4*mup**2*mmo**4-8*p1p
     &   2/mz**4*mup**2*mmo**6+4*p1p3/mz**2*mup**2*mmo**4+4*p1p4/mz**2*mup
     &   **2*mmo**4-4*p1p5/mz**2*mup**2*mmo**4-4*p2p3/mz**2*mup**2*mmo**4-
     &   4*p2p4/mz**2*mup**2*mmo**4+4*p2p5/mz**2*mup**2*mmo**4+8*p3p4/mz**
     &   4*mup**4*mmo**4-2*p3p4*mup**2*mmo**2-8*p3p5/mz**4*mup**4*mmo**4+2
     &   *p3p5*mup**2*mmo**2)
     &   +iz4mo**2*betasprmomo*chizpsc*chizsprc/ps**2/(s-mup**2)*a1z**2/pi
     &   *alpha**3*qmo**2/s*(s-spr)*(8/mz**4*mup**4*mmo**6+4*mup**2*mmo**4
     &   -8*p1p2*p3p4/mz**4*mup**2*mmo**4+8*p1p2*p3p5/mz**4*mup**2*mmo**4+
     &   8*p1p2/mz**4*mup**2*mmo**6-4*p1p3/mz**2*mup**2*mmo**4-4*p1p4/mz**
     &   2*mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**4+4*p2p3/mz**2*mup**2*mm
     &   o**4+4*p2p4/mz**2*mup**2*mmo**4-4*p2p5/mz**2*mup**2*mmo**4-8*p3p4
     &   /mz**4*mup**4*mmo**4+2*p3p4*mup**2*mmo**2+8*p3p5/mz**4*mup**4*mmo
     &   **4-2*p3p5*mup**2*mmo**2)
     &   +iz4mo*betasprmomo*chizps*chizpsc/ps**2/(s-mup**2)/pi*alpha**3*qm
     &   o**2/s*(s-spr)*(aup**2*vmo**2*mup**2*mmo**2+2*p3p4*aup**2*vmo**2*
     &   mup**2-p3p5*aup**2*vmo**2*mup**2)
     &   +iz4mo*betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*q
     &   mo**2/s/spr*(s-spr)*(p3p5/mz**2*mup**2*mmo**2)
     &   +iz4mo*betasprmomo*chizspr*chizpsc/ps**2/(s-mup**2)*a1z**2/pi*alp
     &   ha**3*qmo**2/s*(s-spr)*(-4/mz**4*mup**4*mmo**4+mup**2*mmo**2-8*p1
     &   p2*p3p4/mz**4*mup**2*mmo**2+4*p1p2*p3p5/mz**4*mup**2*mmo**2-4*p1p
     &   2/mz**4*mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**2-4*p2p5/mz**2*mup
     &   **2*mmo**2-8*p3p4/mz**4*mup**4*mmo**2+2*p3p4*mup**2+4*p3p5/mz**4*
     &   mup**4*mmo**2-p3p5*mup**2)
     &   +iz4mo*betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*alpha*
     &   *3*qup*qmo/s/spr*(s-spr)*(-2*p1p4*p3p4/mz**4*mup**2*mmo**2+p1p4*p
     &   3p5/mz**4*mup**2*mmo**2+2*p1p4/mz**4*mup**2*mmo**4+p1p4/mz**2*mup
     &   **2*mmo**2-2*p2p4*p3p4/mz**4*mup**2*mmo**2+p2p4*p3p5/mz**4*mup**2
     &   *mmo**2+2*p2p4/mz**4*mup**2*mmo**4+p2p4/mz**2*mup**2*mmo**2)
     &   +iz4mo*betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup*qmo/s/spr*(s-spr)*(-2*p1p4*p3p4/mz**4*mup**2*mmo**2+p1p4*
     &   p3p5/mz**4*mup**2*mmo**2+2*p1p4/mz**4*mup**2*mmo**4+p1p4/mz**2*mu
     &   p**2*mmo**2-2*p2p4*p3p4/mz**4*mup**2*mmo**2+p2p4*p3p5/mz**4*mup**
     &   2*mmo**2+2*p2p4/mz**4*mup**2*mmo**4+p2p4/mz**2*mup**2*mmo**2)
     &   +iz4mo*betasprmomo*chizpsc**2/ps**2/(s-mup**2)*a1z**2/pi*alpha**3
     &   *qmo**2/s*(s-spr)*(4/mz**4*mup**4*mmo**4-mup**2*mmo**2+8*p1p2*p3p
     &   4/mz**4*mup**2*mmo**2-4*p1p2*p3p5/mz**4*mup**2*mmo**2+4*p1p2/mz**
     &   4*mup**2*mmo**4-4*p1p5/mz**2*mup**2*mmo**2+4*p2p5/mz**2*mup**2*mm
     &   o**2+8*p3p4/mz**4*mup**4*mmo**2-2*p3p4*mup**2-4*p3p5/mz**4*mup**4
     &   *mmo**2+p3p5*mup**2)
     &   +iz4mo*betasprmomo*chizpsc*chizsprc/ps**2/(s-mup**2)*a1z**2/pi*al
     &   pha**3*qmo**2/s*(s-spr)*(-4/mz**4*mup**4*mmo**4+mup**2*mmo**2-8*p
     &   1p2*p3p4/mz**4*mup**2*mmo**2+4*p1p2*p3p5/mz**4*mup**2*mmo**2-4*p1
     &   p2/mz**4*mup**2*mmo**4+4*p1p5/mz**2*mup**2*mmo**2-4*p2p5/mz**2*mu
     &   p**2*mmo**2-8*p3p4/mz**4*mup**4*mmo**2+2*p3p4*mup**2+4*p3p5/mz**4
     &   *mup**4*mmo**2-p3p5*mup**2)
     &   +iz4mo*betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha
     &   **3*qup*qmo/s/spr*(s-spr)*(2*p1p4*p3p4/mz**4*mup**2*mmo**2-p1p4*p
     &   3p5/mz**4*mup**2*mmo**2-2*p1p4/mz**4*mup**2*mmo**4-p1p4/mz**2*mup
     &   **2*mmo**2+2*p2p4*p3p4/mz**4*mup**2*mmo**2-p2p4*p3p5/mz**4*mup**2
     &   *mmo**2-2*p2p4/mz**4*mup**2*mmo**4-p2p4/mz**2*mup**2*mmo**2)
     &   +iz4mo*betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*
     &   qmo**2/s/spr*(s-spr)*(p3p5/mz**2*mup**2*mmo**2)
     &   +iz4mo*betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alpha**3*q
     &   up*qmo/s/spr*(s-spr)*(-2*p1p4*p3p4/mz**4*mup**2*mmo**2+p1p4*p3p5/
     &   mz**4*mup**2*mmo**2+2*p1p4/mz**4*mup**2*mmo**4+p1p4/mz**2*mup**2*
     &   mmo**2-2*p2p4*p3p4/mz**4*mup**2*mmo**2+p2p4*p3p5/mz**4*mup**2*mmo
     &   **2+2*p2p4/mz**4*mup**2*mmo**4+p2p4/mz**2*mup**2*mmo**2)
     &   +betasprmomo*chizspr/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*qmo**2/
     &   s/spr*(s-spr)*(-1d0/mz**2*mup**2*mmo**2)
     &   +betasprmomo*chizspr*chizpsc/ps**2/(s-mup**2)*a1z**2/pi*alpha**3*
     &   qmo**2/s*(s-spr)*(-4/mz**4*mup**4*mmo**2-4*p1p2/mz**4*mup**2*mmo*
     &   *2)
     &   +betasprmomo*chizspr*chizpsc/ps/(s-mup**2)*a1z**2/pi*alpha**3*qup
     &   *qmo/s/spr*(s-spr)*(1d0/2*p1p3/mz**4*mup**2*mmo**2-1d0/2*p1p4/mz*
     &   *4*mup**2*mmo**2+1d0/2*p2p3/mz**4*mup**2*mmo**2-1d0/2*p2p4/mz**4*
     &   mup**2*mmo**2)
     &   +betasprmomo*chizspr*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha**3*qu
     &   p*qmo/s/spr*(s-spr)*(1d0/2*p1p3/mz**4*mup**2*mmo**2-1d0/2*p1p4/mz
     &   **4*mup**2*mmo**2+1d0/2*p2p3/mz**4*mup**2*mmo**2-1d0/2*p2p4/mz**4
     &   *mup**2*mmo**2)
     &   +betasprmomo*chizspr*chizsprc/(s-mup**2)*a1z**2/pi*alpha**3*qup**
     &   2/s/spr**2*(s-spr)*(-4/mz**4*mup**2*mmo**4+4*p3p4/mz**4*mup**2*mm
     &   o**2)
     &   +betasprmomo*chizpsc**2/ps**2/(s-mup**2)*a1z**2/pi*alpha**3*qmo**
     &   2/s*(s-spr)*(4/mz**4*mup**4*mmo**2+4*p1p2/mz**4*mup**2*mmo**2)
     &   +betasprmomo*chizpsc*chizsprc/ps**2/(s-mup**2)*a1z**2/pi*alpha**3
     &   *qmo**2/s*(s-spr)*(-4/mz**4*mup**4*mmo**2-4*p1p2/mz**4*mup**2*mmo
     &   **2)
     &   +betasprmomo*chizpsc*chizsprc/ps/(s-mup**2)*a1z**2/pi*alpha**3*qu
     &   p*qmo/s/spr*(s-spr)*(-1d0/2*p1p3/mz**4*mup**2*mmo**2+1d0/2*p1p4/m
     &   z**4*mup**2*mmo**2-1d0/2*p2p3/mz**4*mup**2*mmo**2+1d0/2*p2p4/mz**
     &   4*mup**2*mmo**2)
     &   +betasprmomo*chizsprc/ps/(s-mup**2)*a1z/pi*alpha**3*qup**2*qmo**2
     &   /s/spr*(s-spr)*(-1d0/mz**2*mup**2*mmo**2)
     &   +betasprmomo*chizsprc**2/ps/(s-mup**2)*a1z**2/pi*alpha**3*qup*qmo
     &   /s/spr*(s-spr)*(1d0/2*p1p3/mz**4*mup**2*mmo**2-1d0/2*p1p4/mz**4*m
     &   up**2*mmo**2+1d0/2*p2p3/mz**4*mup**2*mmo**2-1d0/2*p2p4/mz**4*mup*
     &   *2*mmo**2)

        hard = hard*conhc*cfprime

        return
      end
