#include "CLI11.hpp"
#include "DataSaver.h"
#include "Info.h"
#include "ModulesInterface.h"
#include "PartonDidtributionsLHAPDF.h"
#include "Process_pp.h"
#include "ReneSANCe_pp.h"
#include "SettingsUCL.h"
#include "Time.h"

using namespace SANC;

int main(int argc, char *argv[]) {
  std::vector<std::string> other;
  std::string config_path, output_dir;
  long seed, pid;
  double ecm;
  bool version{false};

  CLI::App options{"ReneSANCe_pp is a Monte-Carlo event generator for "
                   "proton-proton collisions"};
  options.add_option("-f,--file", config_path, "Set path to index.conf file")
      ->check(CLI::ExistingPath);
  options.add_option("-o,--out", output_dir, "Set output dir");
  options.add_option("-s,--seed", seed, "Set seed");
  options.add_option("-p,--pid", pid, "Set process")->check(CLI::Range(201, 223));
  options.add_option("-e,--ecm", ecm, "Set energy of collider");
  options.add_option("-D,--define", other, "Set other settings as list of key:value");
  options.add_flag("--version", version, "Print program version and exit");
  CLI11_PARSE(options, argc, argv);

  if (version) {
    std::cout << "ReneSANCe version "
              << "1.3.8"
              << "\n";
    exit(0);
  }

  SettingsUCL cfg;

  if (options.count("-f") > 0) {
    cfg.setPath(config_path);
  }
  cfg.init();
  if (options.count("-o") > 0) {
    cfg.set("outputDir", output_dir);
  }
  if (options.count("-s") > 0) {
    cfg.set("RanSeed", seed);
  }
  if (options.count("-p") > 0) {
    cfg.set("pid", pid);
  }
  if (options.count("-e") > 0) {
    cfg.set("ecm", ecm);
  }
  for (auto i : other) {
    cfg.set(i);
  }
  // cfg.print();
  cfg.validate();
  cfg.print_diff();
  Info info(cfg);
  PDF *pdf = new PartonDistributionsLHAPDF();
  pdf->init(info.PDFname, info.PDFmember);
  Time timing("run1");
  Process proc(info, pdf);
  ModulesInterface modules(info, proc);
  DataSaver ds(info, proc);
  ReneSANCe_pp *generator(new ReneSANCe_pp(cfg, info, proc, pdf, modules, timing, ds));
  generator->generateEvents();
  delete pdf;

  return 0;
}
